<?php

return [
    '🧑🏻‍❤‍🧑🏼' => 'tayuga s wul: amdan, amdan, taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '🧑🏻‍❤‍🧑🏽' => 'tayuga s wul: amdan, amdan, taglimt taceɛlalt, taglimt talemmast',
    '🧑🏻‍❤‍🧑🏾' => 'tayuga s wul: amdan, amdan, taglimt taceɛlalt, taglimt tubrikt talemmast',
    '🧑🏻‍❤‍🧑🏿' => 'tayuga s wul: amdan, amdan, taglimt taceɛlalt, taglimt tubrikt',
    '🧑🏼‍❤‍🧑🏻' => 'tayuga s wul: amdan, amdan, tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '🧑🏼‍❤‍🧑🏽' => 'tayuga s wul: amdan, amdan, tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '🧑🏼‍❤‍🧑🏾' => 'tayuga s wul: amdan, amdan, tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '🧑🏼‍❤‍🧑🏿' => 'tayuga s wul: amdan, amdan, tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '🧑🏽‍❤‍🧑🏻' => 'tayuga s wul: amdan, amdan, taglimt talemmast, taglimt taceɛlalt',
    '🧑🏽‍❤‍🧑🏼' => 'tayuga s wul: amdan, amdan, taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '🧑🏽‍❤‍🧑🏾' => 'tayuga s wul: amdan, amdan, taglimt talemmast, taglimt tubrikt talemmast',
    '🧑🏽‍❤‍🧑🏿' => 'tayuga s wul: amdan, amdan, taglimt talemmast, taglimt tubrikt',
    '🧑🏾‍❤‍🧑🏻' => 'tayuga s wul: amdan, amdan, taglimt tubrikt talemmast, taglimt taceɛlalt',
    '🧑🏾‍❤‍🧑🏼' => 'tayuga s wul: amdan, amdan, taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '🧑🏾‍❤‍🧑🏽' => 'tayuga s wul: amdan, amdan, taglimt tubrikt talemmast, taglimt talemmast',
    '🧑🏾‍❤‍🧑🏿' => 'tayuga s wul: amdan, amdan, taglimt tubrikt talemmast, taglimt tubrikt',
    '🧑🏿‍❤‍🧑🏻' => 'tayuga s wul: amdan, amdan, taglimt tubrikt, taglimt taceɛlalt',
    '🧑🏿‍❤‍🧑🏼' => 'tayuga s wul: amdan, amdan, taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '🧑🏿‍❤‍🧑🏽' => 'tayuga s wul: amdan, amdan, taglimt tubrikt, taglimt talemmast',
    '🧑🏿‍❤‍🧑🏾' => 'tayuga s wul: amdan, amdan, taglimt tubrikt, taglimt tubrikt talemmast',
    '🧑🏻‍🐰‍🧑🏼' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '🧑🏻‍🐰‍🧑🏽' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt taceɛlalt, taglimt talemmast',
    '🧑🏻‍🐰‍🧑🏾' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt taceɛlalt, taglimt tubrikt talemmast',
    '🧑🏻‍🐰‍🧑🏿' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt taceɛlalt, taglimt tubrikt',
    '🧑🏼‍🐰‍🧑🏻' => 'imdanen s yimeẓẓuɣen n yiwtal: tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '🧑🏼‍🐰‍🧑🏽' => 'imdanen s yimeẓẓuɣen n yiwtal: tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '🧑🏼‍🐰‍🧑🏾' => 'imdanen s yimeẓẓuɣen n yiwtal: tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '🧑🏼‍🐰‍🧑🏿' => 'imdanen s yimeẓẓuɣen n yiwtal: tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '🧑🏽‍🐰‍🧑🏻' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt talemmast, taglimt taceɛlalt',
    '🧑🏽‍🐰‍🧑🏼' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '🧑🏽‍🐰‍🧑🏾' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt talemmast, taglimt tubrikt talemmast',
    '🧑🏽‍🐰‍🧑🏿' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt talemmast, taglimt tubrikt',
    '🧑🏾‍🐰‍🧑🏻' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt talemmast, taglimt taceɛlalt',
    '🧑🏾‍🐰‍🧑🏼' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '🧑🏾‍🐰‍🧑🏽' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt talemmast, taglimt talemmast',
    '🧑🏾‍🐰‍🧑🏿' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt talemmast, taglimt tubrikt',
    '🧑🏿‍🐰‍🧑🏻' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt, taglimt taceɛlalt',
    '🧑🏿‍🐰‍🧑🏼' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '🧑🏿‍🐰‍🧑🏽' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt, taglimt talemmast',
    '🧑🏿‍🐰‍🧑🏾' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt, taglimt tubrikt talemmast',
    '👨🏻‍❤‍👨🏻' => 'tayuga s wul: argaz, argaz, taglimt taceɛlalt',
    '👨🏻‍❤‍👨🏼' => 'tayuga s wul: argaz, argaz, taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '👨🏻‍❤‍👨🏽' => 'tayuga s wul: argaz, argaz, taglimt taceɛlalt, taglimt talemmast',
    '👨🏻‍❤‍👨🏾' => 'tayuga s wul: argaz, argaz, taglimt taceɛlalt, taglimt tubrikt talemmast',
    '👨🏻‍❤‍👨🏿' => 'tayuga s wul: argaz, argaz, taglimt taceɛlalt, taglimt tubrikt',
    '👨🏼‍❤‍👨🏻' => 'tayuga s wul: argaz, argaz, tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '👨🏼‍❤‍👨🏼' => 'tayuga s wul: argaz, argaz, tagwlimt taceɛlalt talemmast',
    '👨🏼‍❤‍👨🏽' => 'tayuga s wul: argaz, argaz, tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '👨🏼‍❤‍👨🏾' => 'tayuga s wul: argaz, argaz, tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '👨🏼‍❤‍👨🏿' => 'tayuga s wul: argaz, argaz, tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '👨🏽‍❤‍👨🏻' => 'tayuga s wul: argaz, argaz, taglimt talemmast, taglimt taceɛlalt',
    '👨🏽‍❤‍👨🏼' => 'tayuga s wul: argaz, argaz, taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '👨🏽‍❤‍👨🏽' => 'tayuga s wul: argaz, argaz, taglimt talemmast',
    '👨🏽‍❤‍👨🏾' => 'tayuga s wul: argaz, argaz, taglimt talemmast, taglimt tubrikt talemmast',
    '👨🏽‍❤‍👨🏿' => 'tayuga s wul: argaz, argaz, taglimt talemmast, taglimt tubrikt',
    '👨🏾‍❤‍👨🏻' => 'tayuga s wul: argaz, argaz, taglimt tubrikt talemmast, taglimt taceɛlalt',
    '👨🏾‍❤‍👨🏼' => 'tayuga s wul: argaz, argaz, taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '👨🏾‍❤‍👨🏽' => 'tayuga s wul: argaz, argaz, taglimt tubrikt talemmast, taglimt talemmast',
    '👨🏾‍❤‍👨🏾' => 'tayuga s wul: argaz, argaz, taglimt tubrikt talemmast',
    '👨🏾‍❤‍👨🏿' => 'tayuga s wul: argaz, argaz, taglimt tubrikt talemmast, taglimt tubrikt',
    '👨🏿‍❤‍👨🏻' => 'tayuga s wul: argaz, argaz, taglimt tubrikt, taglimt taceɛlalt',
    '👨🏿‍❤‍👨🏼' => 'tayuga s wul: argaz, argaz, taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '👨🏿‍❤‍👨🏽' => 'tayuga s wul: argaz, argaz, taglimt tubrikt, taglimt talemmast',
    '👨🏿‍❤‍👨🏾' => 'tayuga s wul: argaz, argaz, taglimt tubrikt, taglimt tubrikt talemmast',
    '👨🏿‍❤‍👨🏿' => 'tayuga s wul: argaz, argaz, taglimt tubrikt',
    '👩🏻‍❤‍👨🏻' => 'tayuga s wul: tameṭṭut, argaz, taglimt taceɛlalt',
    '👩🏻‍❤‍👨🏼' => 'tayuga s wul: tameṭṭut, argaz, taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '👩🏻‍❤‍👨🏽' => 'tayuga s wul: tameṭṭut, argaz, taglimt taceɛlalt, taglimt talemmast',
    '👩🏻‍❤‍👨🏾' => 'tayuga s wul: tameṭṭut, argaz, taglimt taceɛlalt, taglimt tubrikt talemmast',
    '👩🏻‍❤‍👨🏿' => 'tayuga s wul: tameṭṭut, argaz, taglimt taceɛlalt, taglimt tubrikt',
    '👩🏼‍❤‍👨🏻' => 'tayuga s wul: tameṭṭut, argaz, tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '👩🏼‍❤‍👨🏼' => 'tayuga s wul: tameṭṭut, argaz, tagwlimt taceɛlalt talemmast',
    '👩🏼‍❤‍👨🏽' => 'tayuga s wul: tameṭṭut, argaz, tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '👩🏼‍❤‍👨🏾' => 'tayuga s wul: tameṭṭut, argaz, tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '👩🏼‍❤‍👨🏿' => 'tayuga s wul: tameṭṭut, argaz, tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '👩🏽‍❤‍👨🏻' => 'tayuga s wul: tameṭṭut, argaz, taglimt talemmast, taglimt taceɛlalt',
    '👩🏽‍❤‍👨🏼' => 'tayuga s wul: tameṭṭut, argaz, taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏽‍❤‍👨🏽' => 'tayuga s wul: tameṭṭut, argaz, taglimt talemmast',
    '👩🏽‍❤‍👨🏾' => 'tayuga s wul: tameṭṭut, argaz, taglimt talemmast, taglimt tubrikt talemmast',
    '👩🏽‍❤‍👨🏿' => 'tayuga s wul: tameṭṭut, argaz, taglimt talemmast, taglimt tubrikt',
    '👩🏾‍❤‍👨🏻' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt talemmast, taglimt taceɛlalt',
    '👩🏾‍❤‍👨🏼' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏾‍❤‍👨🏽' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt talemmast, taglimt talemmast',
    '👩🏾‍❤‍👨🏾' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt talemmast',
    '👩🏾‍❤‍👨🏿' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt talemmast, taglimt tubrikt',
    '👩🏿‍❤‍👨🏻' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt, taglimt taceɛlalt',
    '👩🏿‍❤‍👨🏼' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '👩🏿‍❤‍👨🏽' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt, taglimt talemmast',
    '👩🏿‍❤‍👨🏾' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt, taglimt tubrikt talemmast',
    '👩🏿‍❤‍👨🏿' => 'tayuga s wul: tameṭṭut, argaz, taglimt tubrikt',
    '👩🏻‍❤‍👩🏻' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt taceɛlalt',
    '👩🏻‍❤‍👩🏼' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '👩🏻‍❤‍👩🏽' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt taceɛlalt, taglimt talemmast',
    '👩🏻‍❤‍👩🏾' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt taceɛlalt, taglimt tubrikt talemmast',
    '👩🏻‍❤‍👩🏿' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt taceɛlalt, taglimt tubrikt',
    '👩🏼‍❤‍👩🏻' => 'tayuga s wul: tameṭṭut, tameṭṭut, tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '👩🏼‍❤‍👩🏼' => 'tayuga s wul: tameṭṭut, tameṭṭut, tagwlimt taceɛlalt talemmast',
    '👩🏼‍❤‍👩🏽' => 'tayuga s wul: tameṭṭut, tameṭṭut, tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '👩🏼‍❤‍👩🏾' => 'tayuga s wul: tameṭṭut, tameṭṭut, tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '👩🏼‍❤‍👩🏿' => 'tayuga s wul: tameṭṭut, tameṭṭut, tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '👩🏽‍❤‍👩🏻' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt talemmast, taglimt taceɛlalt',
    '👩🏽‍❤‍👩🏼' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏽‍❤‍👩🏽' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt talemmast',
    '👩🏽‍❤‍👩🏾' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt talemmast, taglimt tubrikt talemmast',
    '👩🏽‍❤‍👩🏿' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt talemmast, taglimt tubrikt',
    '👩🏾‍❤‍👩🏻' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt talemmast, taglimt taceɛlalt',
    '👩🏾‍❤‍👩🏼' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏾‍❤‍👩🏽' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt talemmast, taglimt talemmast',
    '👩🏾‍❤‍👩🏾' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt talemmast',
    '👩🏾‍❤‍👩🏿' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt talemmast, taglimt tubrikt',
    '👩🏿‍❤‍👩🏻' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt, taglimt taceɛlalt',
    '👩🏿‍❤‍👩🏼' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '👩🏿‍❤‍👩🏽' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt, taglimt talemmast',
    '👩🏿‍❤‍👩🏾' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt, taglimt tubrikt talemmast',
    '👩🏿‍❤‍👩🏿' => 'tayuga s wul: tameṭṭut, tameṭṭut, taglimt tubrikt',
    '👩🏻‍🤝‍👩🏼' => 'tulawin myuṭṭafent ifassen: taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '👩🏻‍🤝‍👩🏽' => 'tulawin myuṭṭafent ifassen: taglimt taceɛlalt, taglimt talemmast',
    '👩🏻‍🤝‍👩🏾' => 'tulawin myuṭṭafent ifassen: taglimt taceɛlalt, taglimt tubrikt talemmast',
    '👩🏻‍🤝‍👩🏿' => 'tulawin myuṭṭafent ifassen: taglimt taceɛlalt, taglimt tubrikt',
    '👩🏼‍🤝‍👩🏻' => 'tulawin myuṭṭafent ifassen: tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '👩🏼‍🤝‍👩🏽' => 'tulawin myuṭṭafent ifassen: tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '👩🏼‍🤝‍👩🏾' => 'tulawin myuṭṭafent ifassen: tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '👩🏼‍🤝‍👩🏿' => 'tulawin myuṭṭafent ifassen: tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '👩🏽‍🤝‍👩🏻' => 'tulawin myuṭṭafent ifassen: taglimt talemmast, taglimt taceɛlalt',
    '👩🏽‍🤝‍👩🏼' => 'tulawin myuṭṭafent ifassen: taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏽‍🤝‍👩🏾' => 'tulawin myuṭṭafent ifassen: taglimt talemmast, taglimt tubrikt talemmast',
    '👩🏽‍🤝‍👩🏿' => 'tulawin myuṭṭafent ifassen: taglimt talemmast, taglimt tubrikt',
    '👩🏾‍🤝‍👩🏻' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt talemmast, taglimt taceɛlalt',
    '👩🏾‍🤝‍👩🏼' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏾‍🤝‍👩🏽' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt talemmast, taglimt talemmast',
    '👩🏾‍🤝‍👩🏿' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt talemmast, taglimt tubrikt',
    '👩🏿‍🤝‍👩🏻' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt, taglimt taceɛlalt',
    '👩🏿‍🤝‍👩🏼' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '👩🏿‍🤝‍👩🏽' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt, taglimt talemmast',
    '👩🏿‍🤝‍👩🏾' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt, taglimt tubrikt talemmast',
    '👩🏻‍🤝‍👨🏼' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '👩🏻‍🤝‍👨🏽' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt taceɛlalt, taglimt talemmast',
    '👩🏻‍🤝‍👨🏾' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt taceɛlalt, taglimt tubrikt talemmast',
    '👩🏻‍🤝‍👨🏿' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt taceɛlalt, taglimt tubrikt',
    '👩🏼‍🤝‍👨🏻' => 'tameṭṭut d urgaz myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '👩🏼‍🤝‍👨🏽' => 'tameṭṭut d urgaz myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '👩🏼‍🤝‍👨🏾' => 'tameṭṭut d urgaz myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '👩🏼‍🤝‍👨🏿' => 'tameṭṭut d urgaz myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '👩🏽‍🤝‍👨🏻' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt talemmast, taglimt taceɛlalt',
    '👩🏽‍🤝‍👨🏼' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏽‍🤝‍👨🏾' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt talemmast, taglimt tubrikt talemmast',
    '👩🏽‍🤝‍👨🏿' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt talemmast, taglimt tubrikt',
    '👩🏾‍🤝‍👨🏻' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt talemmast, taglimt taceɛlalt',
    '👩🏾‍🤝‍👨🏼' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '👩🏾‍🤝‍👨🏽' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt talemmast, taglimt talemmast',
    '👩🏾‍🤝‍👨🏿' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt talemmast, taglimt tubrikt',
    '👩🏿‍🤝‍👨🏻' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt, taglimt taceɛlalt',
    '👩🏿‍🤝‍👨🏼' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '👩🏿‍🤝‍👨🏽' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt, taglimt talemmast',
    '👩🏿‍🤝‍👨🏾' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt, taglimt tubrikt talemmast',
    '👨🏻‍🤝‍👨🏼' => 'irgazen myuṭṭafen ifassen: taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '👨🏻‍🤝‍👨🏽' => 'irgazen myuṭṭafen ifassen: taglimt taceɛlalt, taglimt talemmast',
    '👨🏻‍🤝‍👨🏾' => 'irgazen myuṭṭafen ifassen: taglimt taceɛlalt, taglimt tubrikt talemmast',
    '👨🏻‍🤝‍👨🏿' => 'irgazen myuṭṭafen ifassen: taglimt taceɛlalt, taglimt tubrikt',
    '👨🏼‍🤝‍👨🏻' => 'irgazen myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '👨🏼‍🤝‍👨🏽' => 'irgazen myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '👨🏼‍🤝‍👨🏾' => 'irgazen myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '👨🏼‍🤝‍👨🏿' => 'irgazen myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '👨🏽‍🤝‍👨🏻' => 'irgazen myuṭṭafen ifassen: taglimt talemmast, taglimt taceɛlalt',
    '👨🏽‍🤝‍👨🏼' => 'irgazen myuṭṭafen ifassen: taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '👨🏽‍🤝‍👨🏾' => 'irgazen myuṭṭafen ifassen: taglimt talemmast, taglimt tubrikt talemmast',
    '👨🏽‍🤝‍👨🏿' => 'irgazen myuṭṭafen ifassen: taglimt talemmast, taglimt tubrikt',
    '👨🏾‍🤝‍👨🏻' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt talemmast, taglimt taceɛlalt',
    '👨🏾‍🤝‍👨🏼' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '👨🏾‍🤝‍👨🏽' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt talemmast, taglimt talemmast',
    '👨🏾‍🤝‍👨🏿' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt talemmast, taglimt tubrikt',
    '👨🏿‍🤝‍👨🏻' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt, taglimt taceɛlalt',
    '👨🏿‍🤝‍👨🏼' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '👨🏿‍🤝‍👨🏽' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt, taglimt talemmast',
    '👨🏿‍🤝‍👨🏾' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt, taglimt tubrikt talemmast',
    '👨‍👩‍👧‍👦' => 'tawacult: argaz, tameṭṭut, taqcict, aqcic',
    '👨‍👩‍👦‍👦' => 'tawacult: argaz, tameṭṭut, aqcic, aqcic',
    '👨‍👩‍👧‍👧' => 'tawacult: argaz, tameṭṭut, taqcict, taqcict',
    '👨‍👨‍👧‍👦' => 'tawacult: argaz, argaz, taqcict, aqcic',
    '👨‍👨‍👦‍👦' => 'tawacult: argaz, argaz, aqcic, aqcic',
    '👨‍👨‍👧‍👧' => 'tawacult: argaz, argaz, taqcict, taqcict',
    '👩‍👩‍👧‍👦' => 'tawacult: tameṭṭut, tameṭṭut, taqcict, aqcic',
    '👩‍👩‍👦‍👦' => 'tawacult: tameṭṭut, tameṭṭut, aqcic, aqcic',
    '👩‍👩‍👧‍👧' => 'tawacult: tameṭṭut, tameṭṭut, taqcict, taqcict',
    '🫱🏻‍🫲🏼' => 'amsalem: taglimt taceɛlalt, tagwlimt taceɛlalt talemmast',
    '🫱🏻‍🫲🏽' => 'amsalem: taglimt taceɛlalt, taglimt talemmast',
    '🫱🏻‍🫲🏾' => 'amsalem: taglimt taceɛlalt, taglimt tubrikt talemmast',
    '🫱🏻‍🫲🏿' => 'amsalem: taglimt taceɛlalt, taglimt tubrikt',
    '🫱🏼‍🫲🏻' => 'amsalem: tagwlimt taceɛlalt talemmast, taglimt taceɛlalt',
    '🫱🏼‍🫲🏽' => 'amsalem: tagwlimt taceɛlalt talemmast, taglimt talemmast',
    '🫱🏼‍🫲🏾' => 'amsalem: tagwlimt taceɛlalt talemmast, taglimt tubrikt talemmast',
    '🫱🏼‍🫲🏿' => 'amsalem: tagwlimt taceɛlalt talemmast, taglimt tubrikt',
    '🫱🏽‍🫲🏻' => 'amsalem: taglimt talemmast, taglimt taceɛlalt',
    '🫱🏽‍🫲🏼' => 'amsalem: taglimt talemmast, tagwlimt taceɛlalt talemmast',
    '🫱🏽‍🫲🏾' => 'amsalem: taglimt talemmast, taglimt tubrikt talemmast',
    '🫱🏽‍🫲🏿' => 'amsalem: taglimt talemmast, taglimt tubrikt',
    '🫱🏾‍🫲🏻' => 'amsalem: taglimt tubrikt talemmast, taglimt taceɛlalt',
    '🫱🏾‍🫲🏼' => 'amsalem: taglimt tubrikt talemmast, tagwlimt taceɛlalt talemmast',
    '🫱🏾‍🫲🏽' => 'amsalem: taglimt tubrikt talemmast, taglimt talemmast',
    '🫱🏾‍🫲🏿' => 'amsalem: taglimt tubrikt talemmast, taglimt tubrikt',
    '🫱🏿‍🫲🏻' => 'amsalem: taglimt tubrikt, taglimt taceɛlalt',
    '🫱🏿‍🫲🏼' => 'amsalem: taglimt tubrikt, tagwlimt taceɛlalt talemmast',
    '🫱🏿‍🫲🏽' => 'amsalem: taglimt tubrikt, taglimt talemmast',
    '🫱🏿‍🫲🏾' => 'amsalem: taglimt tubrikt, taglimt tubrikt talemmast',
    '👩‍❤‍👨' => 'tayuga s wul: tameṭṭut, argaz',
    '👨‍❤‍👨' => 'tayuga s wul: argaz, argaz',
    '👩‍❤‍👩' => 'tayuga s wul: tameṭṭut, tameṭṭut',
    '👨‍👩‍👦' => 'tawacult: argaz, tameṭṭut, aqcic',
    '👨‍👩‍👧' => 'tawacult: argaz, tameṭṭut, taqcict',
    '👨‍👨‍👦' => 'tawacult: argaz, argaz, aqcic',
    '👨‍👨‍👧' => 'tawacult: argaz, argaz, taqcict',
    '👩‍👩‍👦' => 'tawacult: tameṭṭut, tameṭṭut, aqcic',
    '👩‍👩‍👧' => 'tawacult: tameṭṭut, tameṭṭut, taqcict',
    '👨‍👦‍👦' => 'tawacult: argaz, aqcic, aqcic',
    '👨‍👧‍👦' => 'tawacult: argaz, taqcict, aqcic',
    '👨‍👧‍👧' => 'tawacult: argaz, taqcict, taqcict',
    '👩‍👦‍👦' => 'tawacult: tameṭṭut, aqcic, aqcic',
    '👩‍👧‍👦' => 'tawacult: tameṭṭut, taqcict, aqcic',
    '👩‍👧‍👧' => 'tawacult: tameṭṭut, taqcict, taqcict',
    '🧑🏻‍🦰' => 'amdan: taglimt taceɛlalt, acekkuḥ azeggaɣ',
    '🧑🏼‍🦰' => 'amdan: tagwlimt taceɛlalt talemmast, acekkuḥ azeggaɣ',
    '🧑🏽‍🦰' => 'amdan: taglimt talemmast, acekkuḥ azeggaɣ',
    '🧑🏾‍🦰' => 'amdan: taglimt tubrikt talemmast, acekkuḥ azeggaɣ',
    '🧑🏿‍🦰' => 'amdan: taglimt tubrikt, acekkuḥ azeggaɣ',
    '🧑🏻‍🦱' => 'amdan: taglimt taceɛlalt, acekkuḥ akerṭuṭfan',
    '🧑🏼‍🦱' => 'amdan: tagwlimt taceɛlalt talemmast, acekkuḥ akerṭuṭfan',
    '🧑🏽‍🦱' => 'amdan: taglimt talemmast, acekkuḥ akerṭuṭfan',
    '🧑🏾‍🦱' => 'amdan: taglimt tubrikt talemmast, acekkuḥ akerṭuṭfan',
    '🧑🏿‍🦱' => 'amdan: taglimt tubrikt, acekkuḥ akerṭuṭfan',
    '🧑🏻‍🦳' => 'amdan: taglimt taceɛlalt, acekkuḥ amellal',
    '🧑🏼‍🦳' => 'amdan: tagwlimt taceɛlalt talemmast, acekkuḥ amellal',
    '🧑🏽‍🦳' => 'amdan: taglimt talemmast, acekkuḥ amellal',
    '🧑🏾‍🦳' => 'amdan: taglimt tubrikt talemmast, acekkuḥ amellal',
    '🧑🏿‍🦳' => 'amdan: taglimt tubrikt, acekkuḥ amellal',
    '🧑🏻‍🦲' => 'amdan: taglimt taceɛlalt, aferḍas',
    '🧑🏼‍🦲' => 'amdan: tagwlimt taceɛlalt talemmast, aferḍas',
    '🧑🏽‍🦲' => 'amdan: taglimt talemmast, aferḍas',
    '🧑🏾‍🦲' => 'amdan: taglimt tubrikt talemmast, aferḍas',
    '🧑🏿‍🦲' => 'amdan: taglimt tubrikt, aferḍas',
    '🧔🏻‍♂' => 'argaz: taglimt taceɛlalt, tamart',
    '🧔🏼‍♂' => 'argaz: tagwlimt taceɛlalt talemmast, tamart',
    '🧔🏽‍♂' => 'argaz: taglimt talemmast, tamart',
    '🧔🏾‍♂' => 'argaz: taglimt tubrikt talemmast, tamart',
    '🧔🏿‍♂' => 'argaz: taglimt tubrikt, tamart',
    '👱🏻‍♂' => 'argaz: taglimt taceɛlalt, acebbub aceɛlla',
    '👱🏼‍♂' => 'argaz: tagwlimt taceɛlalt talemmast, acebbub aceɛlla',
    '👱🏽‍♂' => 'argaz: taglimt talemmast, acebbub aceɛlla',
    '👱🏾‍♂' => 'argaz: taglimt tubrikt talemmast, acebbub aceɛlla',
    '👱🏿‍♂' => 'argaz: taglimt tubrikt, acebbub aceɛlla',
    '👨🏻‍🦰' => 'argaz: taglimt taceɛlalt, acekkuḥ azeggaɣ',
    '👨🏼‍🦰' => 'argaz: tagwlimt taceɛlalt talemmast, acekkuḥ azeggaɣ',
    '👨🏽‍🦰' => 'argaz: taglimt talemmast, acekkuḥ azeggaɣ',
    '👨🏾‍🦰' => 'argaz: taglimt tubrikt talemmast, acekkuḥ azeggaɣ',
    '👨🏿‍🦰' => 'argaz: taglimt tubrikt, acekkuḥ azeggaɣ',
    '👨🏻‍🦱' => 'argaz: taglimt taceɛlalt, acekkuḥ akerṭuṭfan',
    '👨🏼‍🦱' => 'argaz: tagwlimt taceɛlalt talemmast, acekkuḥ akerṭuṭfan',
    '👨🏽‍🦱' => 'argaz: taglimt talemmast, acekkuḥ akerṭuṭfan',
    '👨🏾‍🦱' => 'argaz: taglimt tubrikt talemmast, acekkuḥ akerṭuṭfan',
    '👨🏿‍🦱' => 'argaz: taglimt tubrikt, acekkuḥ akerṭuṭfan',
    '👨🏻‍🦳' => 'argaz: taglimt taceɛlalt, acekkuḥ amellal',
    '👨🏼‍🦳' => 'argaz: tagwlimt taceɛlalt talemmast, acekkuḥ amellal',
    '👨🏽‍🦳' => 'argaz: taglimt talemmast, acekkuḥ amellal',
    '👨🏾‍🦳' => 'argaz: taglimt tubrikt talemmast, acekkuḥ amellal',
    '👨🏿‍🦳' => 'argaz: taglimt tubrikt, acekkuḥ amellal',
    '👨🏻‍🦲' => 'argaz: taglimt taceɛlalt, aferḍas',
    '👨🏼‍🦲' => 'argaz: tagwlimt taceɛlalt talemmast, aferḍas',
    '👨🏽‍🦲' => 'argaz: taglimt talemmast, aferḍas',
    '👨🏾‍🦲' => 'argaz: taglimt tubrikt talemmast, aferḍas',
    '👨🏿‍🦲' => 'argaz: taglimt tubrikt, aferḍas',
    '🧔🏻‍♀' => 'tameṭṭut: taglimt taceɛlalt, tamart',
    '🧔🏼‍♀' => 'tameṭṭut: tagwlimt taceɛlalt talemmast, tamart',
    '🧔🏽‍♀' => 'tameṭṭut: taglimt talemmast, tamart',
    '🧔🏾‍♀' => 'tameṭṭut: taglimt tubrikt talemmast, tamart',
    '🧔🏿‍♀' => 'tameṭṭut: taglimt tubrikt, tamart',
    '👱🏻‍♀' => 'tameṭṭut: taglimt taceɛlalt, acebbub awreɣ',
    '👱🏼‍♀' => 'tameṭṭut: tagwlimt taceɛlalt talemmast, acebbub awreɣ',
    '👱🏽‍♀' => 'tameṭṭut: taglimt talemmast, acebbub awreɣ',
    '👱🏾‍♀' => 'tameṭṭut: taglimt tubrikt talemmast, acebbub awreɣ',
    '👱🏿‍♀' => 'tameṭṭut: taglimt tubrikt, acebbub awreɣ',
    '👩🏻‍🦰' => 'tameṭṭut: taglimt taceɛlalt, acekkuḥ azeggaɣ',
    '👩🏼‍🦰' => 'tameṭṭut: tagwlimt taceɛlalt talemmast, acekkuḥ azeggaɣ',
    '👩🏽‍🦰' => 'tameṭṭut: taglimt talemmast, acekkuḥ azeggaɣ',
    '👩🏾‍🦰' => 'tameṭṭut: taglimt tubrikt talemmast, acekkuḥ azeggaɣ',
    '👩🏿‍🦰' => 'tameṭṭut: taglimt tubrikt, acekkuḥ azeggaɣ',
    '👩🏻‍🦱' => 'tameṭṭut: taglimt taceɛlalt, acekkuḥ akerṭuṭfan',
    '👩🏼‍🦱' => 'tameṭṭut: tagwlimt taceɛlalt talemmast, acekkuḥ akerṭuṭfan',
    '👩🏽‍🦱' => 'tameṭṭut: taglimt talemmast, acekkuḥ akerṭuṭfan',
    '👩🏾‍🦱' => 'tameṭṭut: taglimt tubrikt talemmast, acekkuḥ akerṭuṭfan',
    '👩🏿‍🦱' => 'tameṭṭut: taglimt tubrikt, acekkuḥ akerṭuṭfan',
    '👩🏻‍🦳' => 'tameṭṭut: taglimt taceɛlalt, acekkuḥ amellal',
    '👩🏼‍🦳' => 'tameṭṭut: tagwlimt taceɛlalt talemmast, acekkuḥ amellal',
    '👩🏽‍🦳' => 'tameṭṭut: taglimt talemmast, acekkuḥ amellal',
    '👩🏾‍🦳' => 'tameṭṭut: taglimt tubrikt talemmast, acekkuḥ amellal',
    '👩🏿‍🦳' => 'tameṭṭut: taglimt tubrikt, acekkuḥ amellal',
    '👩🏻‍🦲' => 'tameṭṭut: taglimt taceɛlalt, aferḍas',
    '👩🏼‍🦲' => 'tameṭṭut: tagwlimt taceɛlalt talemmast, aferḍas',
    '👩🏽‍🦲' => 'tameṭṭut: taglimt talemmast, aferḍas',
    '👩🏾‍🦲' => 'tameṭṭut: taglimt tubrikt talemmast, aferḍas',
    '👩🏿‍🦲' => 'tameṭṭut: taglimt tubrikt, aferḍas',
    '🙍🏻‍♂' => 'argaz imesxenfeṛ: taglimt taceɛlalt',
    '🙍🏼‍♂' => 'argaz imesxenfeṛ: tagwlimt taceɛlalt talemmast',
    '🙍🏽‍♂' => 'argaz imesxenfeṛ: taglimt talemmast',
    '🙍🏾‍♂' => 'argaz imesxenfeṛ: taglimt tubrikt talemmast',
    '🙍🏿‍♂' => 'argaz imesxenfeṛ: taglimt tubrikt',
    '🙍🏻‍♀' => 'tameṭṭut timesxenfeṛt: taglimt taceɛlalt',
    '🙍🏼‍♀' => 'tameṭṭut timesxenfeṛt: tagwlimt taceɛlalt talemmast',
    '🙍🏽‍♀' => 'tameṭṭut timesxenfeṛt: taglimt talemmast',
    '🙍🏾‍♀' => 'tameṭṭut timesxenfeṛt: taglimt tubrikt talemmast',
    '🙍🏿‍♀' => 'tameṭṭut timesxenfeṛt: taglimt tubrikt',
    '🙎🏻‍♂' => 'argaz imcennef: taglimt taceɛlalt',
    '🙎🏼‍♂' => 'argaz imcennef: tagwlimt taceɛlalt talemmast',
    '🙎🏽‍♂' => 'argaz imcennef: taglimt talemmast',
    '🙎🏾‍♂' => 'argaz imcennef: taglimt tubrikt talemmast',
    '🙎🏿‍♂' => 'argaz imcennef: taglimt tubrikt',
    '🙎🏻‍♀' => 'tameṭṭut timcenneft: taglimt taceɛlalt',
    '🙎🏼‍♀' => 'tameṭṭut timcenneft: tagwlimt taceɛlalt talemmast',
    '🙎🏽‍♀' => 'tameṭṭut timcenneft: taglimt talemmast',
    '🙎🏾‍♀' => 'tameṭṭut timcenneft: taglimt tubrikt talemmast',
    '🙎🏿‍♀' => 'tameṭṭut timcenneft: taglimt tubrikt',
    '🧏🏻‍♂' => 'argaz aεeẓẓug: taglimt taceɛlalt',
    '🧏🏼‍♂' => 'argaz aεeẓẓug: tagwlimt taceɛlalt talemmast',
    '🧏🏽‍♂' => 'argaz aεeẓẓug: taglimt talemmast',
    '🧏🏾‍♂' => 'argaz aεeẓẓug: taglimt tubrikt talemmast',
    '🧏🏿‍♂' => 'argaz aεeẓẓug: taglimt tubrikt',
    '🧏🏻‍♀' => 'tameṭṭut taεeẓẓugt: taglimt taceɛlalt',
    '🧏🏼‍♀' => 'tameṭṭut taεeẓẓugt: tagwlimt taceɛlalt talemmast',
    '🧏🏽‍♀' => 'tameṭṭut taεeẓẓugt: taglimt talemmast',
    '🧏🏾‍♀' => 'tameṭṭut taεeẓẓugt: taglimt tubrikt talemmast',
    '🧏🏿‍♀' => 'tameṭṭut taεeẓẓugt: taglimt tubrikt',
    '🙇🏻‍♂' => 'argaz yettanez: taglimt taceɛlalt',
    '🙇🏼‍♂' => 'argaz yettanez: tagwlimt taceɛlalt talemmast',
    '🙇🏽‍♂' => 'argaz yettanez: taglimt talemmast',
    '🙇🏾‍♂' => 'argaz yettanez: taglimt tubrikt talemmast',
    '🙇🏿‍♂' => 'argaz yettanez: taglimt tubrikt',
    '🙇🏻‍♀' => 'tameṭṭut tettanez: taglimt taceɛlalt',
    '🙇🏼‍♀' => 'tameṭṭut tettanez: tagwlimt taceɛlalt talemmast',
    '🙇🏽‍♀' => 'tameṭṭut tettanez: taglimt talemmast',
    '🙇🏾‍♀' => 'tameṭṭut tettanez: taglimt tubrikt talemmast',
    '🙇🏿‍♀' => 'tameṭṭut tettanez: taglimt tubrikt',
    '🧑🏻‍🎓' => 'anelmad: taglimt taceɛlalt',
    '🧑🏼‍🎓' => 'anelmad: tagwlimt taceɛlalt talemmast',
    '🧑🏽‍🎓' => 'anelmad: taglimt talemmast',
    '🧑🏾‍🎓' => 'anelmad: taglimt tubrikt talemmast',
    '🧑🏿‍🎓' => 'anelmad: taglimt tubrikt',
    '👨🏻‍🎓' => 'argaz anelmad: taglimt taceɛlalt',
    '👨🏼‍🎓' => 'argaz anelmad: tagwlimt taceɛlalt talemmast',
    '👨🏽‍🎓' => 'argaz anelmad: taglimt talemmast',
    '👨🏾‍🎓' => 'argaz anelmad: taglimt tubrikt talemmast',
    '👨🏿‍🎓' => 'argaz anelmad: taglimt tubrikt',
    '👩🏻‍🎓' => 'tameṭṭut tanelmadt: taglimt taceɛlalt',
    '👩🏼‍🎓' => 'tameṭṭut tanelmadt: tagwlimt taceɛlalt talemmast',
    '👩🏽‍🎓' => 'tameṭṭut tanelmadt: taglimt talemmast',
    '👩🏾‍🎓' => 'tameṭṭut tanelmadt: taglimt tubrikt talemmast',
    '👩🏿‍🎓' => 'tameṭṭut tanelmadt: taglimt tubrikt',
    '🧑🏻‍🏫' => 'aselmad: taglimt taceɛlalt',
    '🧑🏼‍🏫' => 'aselmad: tagwlimt taceɛlalt talemmast',
    '🧑🏽‍🏫' => 'aselmad: taglimt talemmast',
    '🧑🏾‍🏫' => 'aselmad: taglimt tubrikt talemmast',
    '🧑🏿‍🏫' => 'aselmad: taglimt tubrikt',
    '👨🏻‍🏫' => 'argaz aselmad: taglimt taceɛlalt',
    '👨🏼‍🏫' => 'argaz aselmad: tagwlimt taceɛlalt talemmast',
    '👨🏽‍🏫' => 'argaz aselmad: taglimt talemmast',
    '👨🏾‍🏫' => 'argaz aselmad: taglimt tubrikt talemmast',
    '👨🏿‍🏫' => 'argaz aselmad: taglimt tubrikt',
    '👩🏻‍🏫' => 'tameṭṭut taselmadt: taglimt taceɛlalt',
    '👩🏼‍🏫' => 'tameṭṭut taselmadt: tagwlimt taceɛlalt talemmast',
    '👩🏽‍🏫' => 'tameṭṭut taselmadt: taglimt talemmast',
    '👩🏾‍🏫' => 'tameṭṭut taselmadt: taglimt tubrikt talemmast',
    '👩🏿‍🏫' => 'tameṭṭut taselmadt: taglimt tubrikt',
    '🚶🏻‍♂' => 'argaz ileḥḥun: taglimt taceɛlalt',
    '🚶🏼‍♂' => 'argaz ileḥḥun: tagwlimt taceɛlalt talemmast',
    '🚶🏽‍♂' => 'argaz ileḥḥun: taglimt talemmast',
    '🚶🏾‍♂' => 'argaz ileḥḥun: taglimt tubrikt talemmast',
    '🚶🏿‍♂' => 'argaz ileḥḥun: taglimt tubrikt',
    '🚶🏻‍♀' => 'tameṭṭut ileḥḥun: taglimt taceɛlalt',
    '🚶🏼‍♀' => 'tameṭṭut ileḥḥun: tagwlimt taceɛlalt talemmast',
    '🚶🏽‍♀' => 'tameṭṭut ileḥḥun: taglimt talemmast',
    '🚶🏾‍♀' => 'tameṭṭut ileḥḥun: taglimt tubrikt talemmast',
    '🚶🏿‍♀' => 'tameṭṭut ileḥḥun: taglimt tubrikt',
    '🧍🏻‍♂' => 'argaz ibedden: taglimt taceɛlalt',
    '🧍🏼‍♂' => 'argaz ibedden: tagwlimt taceɛlalt talemmast',
    '🧍🏽‍♂' => 'argaz ibedden: taglimt talemmast',
    '🧍🏾‍♂' => 'argaz ibedden: taglimt tubrikt talemmast',
    '🧍🏿‍♂' => 'argaz ibedden: taglimt tubrikt',
    '🧍🏻‍♀' => 'tameṭṭut ibedden: taglimt taceɛlalt',
    '🧍🏼‍♀' => 'tameṭṭut ibedden: tagwlimt taceɛlalt talemmast',
    '🧍🏽‍♀' => 'tameṭṭut ibedden: taglimt talemmast',
    '🧍🏾‍♀' => 'tameṭṭut ibedden: taglimt tubrikt talemmast',
    '🧍🏿‍♀' => 'tameṭṭut ibedden: taglimt tubrikt',
    '🧎🏻‍♂' => 'argaz ɣef tgecrar: taglimt taceɛlalt',
    '🧎🏼‍♂' => 'argaz ɣef tgecrar: tagwlimt taceɛlalt talemmast',
    '🧎🏽‍♂' => 'argaz ɣef tgecrar: taglimt talemmast',
    '🧎🏾‍♂' => 'argaz ɣef tgecrar: taglimt tubrikt talemmast',
    '🧎🏿‍♂' => 'argaz ɣef tgecrar: taglimt tubrikt',
    '🧎🏻‍♀' => 'tameṭṭut ɣef tgecrar: taglimt taceɛlalt',
    '🧎🏼‍♀' => 'tameṭṭut ɣef tgecrar: tagwlimt taceɛlalt talemmast',
    '🧎🏽‍♀' => 'tameṭṭut ɣef tgecrar: taglimt talemmast',
    '🧎🏾‍♀' => 'tameṭṭut ɣef tgecrar: taglimt tubrikt talemmast',
    '🧎🏿‍♀' => 'tameṭṭut ɣef tgecrar: taglimt tubrikt',
    '🏃🏻‍♂' => 'argaz yettazzalen: taglimt taceɛlalt',
    '🏃🏼‍♂' => 'argaz yettazzalen: tagwlimt taceɛlalt talemmast',
    '🏃🏽‍♂' => 'argaz yettazzalen: taglimt talemmast',
    '🏃🏾‍♂' => 'argaz yettazzalen: taglimt tubrikt talemmast',
    '🏃🏿‍♂' => 'argaz yettazzalen: taglimt tubrikt',
    '🏃🏻‍♀' => 'tameṭṭut yettazzalen: taglimt taceɛlalt',
    '🏃🏼‍♀' => 'tameṭṭut yettazzalen: tagwlimt taceɛlalt talemmast',
    '🏃🏽‍♀' => 'tameṭṭut yettazzalen: taglimt talemmast',
    '🏃🏾‍♀' => 'tameṭṭut yettazzalen: taglimt tubrikt talemmast',
    '🏃🏿‍♀' => 'tameṭṭut yettazzalen: taglimt tubrikt',
    '🧑‍🦰' => 'amdan: acekkuḥ azeggaɣ',
    '🧑‍🦱' => 'amdan: acekkuḥ akerṭuṭfan',
    '🧑‍🦳' => 'amdan: acekkuḥ amellal',
    '🧑‍🦲' => 'amdan: aferḍas',
    '👨‍🦰' => 'argaz: acekkuḥ azeggaɣ',
    '👨‍🦱' => 'argaz: acekkuḥ akerṭuṭfan',
    '👨‍🦳' => 'argaz: acekkuḥ amellal',
    '👨‍🦲' => 'argaz: aferḍas',
    '👩‍🦰' => 'tameṭṭut: acekkuḥ azeggaɣ',
    '👩‍🦱' => 'tameṭṭut: acekkuḥ akerṭuṭfan',
    '👩‍🦳' => 'tameṭṭut: acekkuḥ amellal',
    '👩‍🦲' => 'tameṭṭut: aferḍas',
    '👨‍👦' => 'tawacult: argaz, aqcic',
    '👨‍👧' => 'tawacult: argaz, taqcict',
    '👩‍👦' => 'tawacult: tameṭṭut, aqcic',
    '👩‍👧' => 'tawacult: tameṭṭut, taqcict',
    '😶‍🌫' => 'udem deg usigna',
    '😮‍💨' => 'udem ittenferrihen',
    '🙂‍↕' => 'ahuzzu aratak n uqerru',
    '😵‍💫' => 'udem s wallen idewwiren',
    '❤‍🔥' => 'ul tecɛel deg-s tmes',
    '❤‍🩹' => 'adi n wul',
    '👁‍🗨' => 'tiṭ deg tnaka n wawal',
    '🧔‍♂' => 'argaz: tamart',
    '👱‍♂' => 'argaz: acebbub aceɛlla',
    '🧔‍♀' => 'tameṭṭut: tamart',
    '👱‍♀' => 'tameṭṭut: acebbub awreɣ',
    '🙍‍♂' => 'argaz imesxenfeṛ',
    '🙍‍♀' => 'tameṭṭut timesxenfeṛt',
    '🙎‍♂' => 'argaz imcennef',
    '🙎‍♀' => 'tameṭṭut timcenneft',
    '🧏‍♂' => 'argaz aεeẓẓug',
    '🧏‍♀' => 'tameṭṭut taεeẓẓugt',
    '🙇‍♂' => 'argaz yettanez',
    '🙇‍♀' => 'tameṭṭut tettanez',
    '🧑‍🎓' => 'anelmad',
    '👨‍🎓' => 'argaz anelmad',
    '👩‍🎓' => 'tameṭṭut tanelmadt',
    '🧑‍🏫' => 'aselmad',
    '👨‍🏫' => 'argaz aselmad',
    '👩‍🏫' => 'tameṭṭut taselmadt',
    '🧟‍♂' => 'argaz aẓumbi',
    '🧟‍♀' => 'tameṭṭut taẓumbit',
    '🚶‍♂' => 'argaz ileḥḥun',
    '🚶‍♀' => 'tameṭṭut ileḥḥun',
    '🧍‍♂' => 'argaz ibedden',
    '🧍‍♀' => 'tameṭṭut ibedden',
    '🧎‍♂' => 'argaz ɣef tgecrar',
    '🧎‍♀' => 'tameṭṭut ɣef tgecrar',
    '🏃‍♂' => 'argaz yettazzalen',
    '🏃‍♀' => 'tameṭṭut yettazzalen',
    '🐕‍🦺' => 'aqjun n uxeddim',
    '🐈‍⬛' => 'amcic aberkan',
    '🐻‍❄' => 'ursu n ugdiz',
    '🐦‍⬛' => 'agerfiw',
    '🐦‍🔥' => 'afiniks',
    '🍋‍🟩' => 'taqarest',
    '🍄‍🟫' => 'tareɣlet taqehwit',
    '🏳‍🌈' => 'anay n teslit n unẓar',
    '🏳‍⚧' => 'anay n urgaz meṭṭu',
    '🏴‍☠' => 'anay n yiflisen',
    '👋🏻' => 'afus yettwehhin: taglimt taceɛlalt',
    '👋🏼' => 'afus yettwehhin: tagwlimt taceɛlalt talemmast',
    '👋🏽' => 'afus yettwehhin: taglimt talemmast',
    '👋🏾' => 'afus yettwehhin: taglimt tubrikt talemmast',
    '👋🏿' => 'afus yettwehhin: taglimt tubrikt',
    '🤚🏻' => 'talwaḥt n ufus irefden: taglimt taceɛlalt',
    '🤚🏼' => 'talwaḥt n ufus irefden: tagwlimt taceɛlalt talemmast',
    '🤚🏽' => 'talwaḥt n ufus irefden: taglimt talemmast',
    '🤚🏾' => 'talwaḥt n ufus irefden: taglimt tubrikt talemmast',
    '🤚🏿' => 'talwaḥt n ufus irefden: taglimt tubrikt',
    '🖐🏻' => 'afus s yiḍudan yeldin: taglimt taceɛlalt',
    '🖐🏼' => 'afus s yiḍudan yeldin: tagwlimt taceɛlalt talemmast',
    '🖐🏽' => 'afus s yiḍudan yeldin: taglimt talemmast',
    '🖐🏾' => 'afus s yiḍudan yeldin: taglimt tubrikt talemmast',
    '🖐🏿' => 'afus s yiḍudan yeldin: taglimt tubrikt',
    '✋🏻' => 'argaz: acebbub awreɣ: taglimt taceɛlalt',
    '✋🏼' => 'argaz: acebbub awreɣ: tagwlimt taceɛlalt talemmast',
    '✋🏽' => 'argaz: acebbub awreɣ: taglimt talemmast',
    '✋🏾' => 'argaz: acebbub awreɣ: taglimt tubrikt talemmast',
    '✋🏿' => 'argaz: acebbub awreɣ: taglimt tubrikt',
    '🖖🏻' => 'aburkan n tezmert: taglimt taceɛlalt',
    '🖖🏼' => 'aburkan n tezmert: tagwlimt taceɛlalt talemmast',
    '🖖🏽' => 'aburkan n tezmert: taglimt talemmast',
    '🖖🏾' => 'aburkan n tezmert: taglimt tubrikt talemmast',
    '🖖🏿' => 'aburkan n tezmert: taglimt tubrikt',
    '🫱🏻' => 'afus ayeffus: taglimt taceɛlalt',
    '🫱🏼' => 'afus ayeffus: tagwlimt taceɛlalt talemmast',
    '🫱🏽' => 'afus ayeffus: taglimt talemmast',
    '🫱🏾' => 'afus ayeffus: taglimt tubrikt talemmast',
    '🫱🏿' => 'afus ayeffus: taglimt tubrikt',
    '🫲🏻' => 'afus azelmaḍ: taglimt taceɛlalt',
    '🫲🏼' => 'afus azelmaḍ: tagwlimt taceɛlalt talemmast',
    '🫲🏽' => 'afus azelmaḍ: taglimt talemmast',
    '🫲🏾' => 'afus azelmaḍ: taglimt tubrikt talemmast',
    '🫲🏿' => 'afus azelmaḍ: taglimt tubrikt',
    '🫳🏻' => 'tidikelt d akesser: taglimt taceɛlalt',
    '🫳🏼' => 'tidikelt d akesser: tagwlimt taceɛlalt talemmast',
    '🫳🏽' => 'tidikelt d akesser: taglimt talemmast',
    '🫳🏾' => 'tidikelt d akesser: taglimt tubrikt talemmast',
    '🫳🏿' => 'tidikelt d akesser: taglimt tubrikt',
    '🫴🏻' => 'tidikelt d asawen: taglimt taceɛlalt',
    '🫴🏼' => 'tidikelt d asawen: tagwlimt taceɛlalt talemmast',
    '🫴🏽' => 'tidikelt d asawen: taglimt talemmast',
    '🫴🏾' => 'tidikelt d asawen: taglimt tubrikt talemmast',
    '🫴🏿' => 'tidikelt d asawen: taglimt tubrikt',
    '🫷🏻' => 'afus ijebden ɣer zelmeḍ: taglimt taceɛlalt',
    '🫷🏼' => 'afus ijebden ɣer zelmeḍ: tagwlimt taceɛlalt talemmast',
    '🫷🏽' => 'afus ijebden ɣer zelmeḍ: taglimt talemmast',
    '🫷🏾' => 'afus ijebden ɣer zelmeḍ: taglimt tubrikt talemmast',
    '🫷🏿' => 'afus ijebden ɣer zelmeḍ: taglimt tubrikt',
    '🫸🏻' => 'afus ijebden ɣer yeffus: taglimt taceɛlalt',
    '🫸🏼' => 'afus ijebden ɣer yeffus: tagwlimt taceɛlalt talemmast',
    '🫸🏽' => 'afus ijebden ɣer yeffus: taglimt talemmast',
    '🫸🏾' => 'afus ijebden ɣer yeffus: taglimt tubrikt talemmast',
    '🫸🏿' => 'afus ijebden ɣer yeffus: taglimt tubrikt',
    '👌🏻' => 'afus n IH: taglimt taceɛlalt',
    '👌🏼' => 'afus n IH: tagwlimt taceɛlalt talemmast',
    '👌🏽' => 'afus n IH: taglimt talemmast',
    '👌🏾' => 'afus n IH: taglimt tubrikt talemmast',
    '👌🏿' => 'afus n IH: taglimt tubrikt',
    '🤌🏻' => 'Iduḍan yemlalen: taglimt taceɛlalt',
    '🤌🏼' => 'Iduḍan yemlalen: tagwlimt taceɛlalt talemmast',
    '🤌🏽' => 'Iduḍan yemlalen: taglimt talemmast',
    '🤌🏾' => 'Iduḍan yemlalen: taglimt tubrikt talemmast',
    '🤌🏿' => 'Iduḍan yemlalen: taglimt tubrikt',
    '🤏🏻' => 'tubbya n ufus: taglimt taceɛlalt',
    '🤏🏼' => 'tubbya n ufus: tagwlimt taceɛlalt talemmast',
    '🤏🏽' => 'tubbya n ufus: taglimt talemmast',
    '🤏🏾' => 'tubbya n ufus: taglimt tubrikt talemmast',
    '🤏🏿' => 'tubbya n ufus: taglimt tubrikt',
    '✌🏻' => 'afus n rrbeḥ: taglimt taceɛlalt',
    '✌🏼' => 'afus n rrbeḥ: tagwlimt taceɛlalt talemmast',
    '✌🏽' => 'afus n rrbeḥ: taglimt talemmast',
    '✌🏾' => 'afus n rrbeḥ: taglimt tubrikt talemmast',
    '✌🏿' => 'afus n rrbeḥ: taglimt tubrikt',
    '🤞🏻' => 'iḍudan yemcubbaken: taglimt taceɛlalt',
    '🤞🏼' => 'iḍudan yemcubbaken: tagwlimt taceɛlalt talemmast',
    '🤞🏽' => 'iḍudan yemcubbaken: taglimt talemmast',
    '🤞🏾' => 'iḍudan yemcubbaken: taglimt tubrikt talemmast',
    '🤞🏿' => 'iḍudan yemcubbaken: taglimt tubrikt',
    '🫰🏻' => 'afus s udebbuz d ccahed yemcubbaken: taglimt taceɛlalt',
    '🫰🏼' => 'afus s udebbuz d ccahed yemcubbaken: tagwlimt taceɛlalt talemmast',
    '🫰🏽' => 'afus s udebbuz d ccahed yemcubbaken: taglimt talemmast',
    '🫰🏾' => 'afus s udebbuz d ccahed yemcubbaken: taglimt tubrikt talemmast',
    '🫰🏿' => 'afus s udebbuz d ccahed yemcubbaken: taglimt tubrikt',
    '🤟🏻' => 'afus n tayri: taglimt taceɛlalt',
    '🤟🏼' => 'afus n tayri: tagwlimt taceɛlalt talemmast',
    '🤟🏽' => 'afus n tayri: taglimt talemmast',
    '🤟🏾' => 'afus n tayri: taglimt tubrikt talemmast',
    '🤟🏿' => 'afus n tayri: taglimt tubrikt',
    '🤘🏻' => 'azamul n wacciwen: taglimt taceɛlalt',
    '🤘🏼' => 'azamul n wacciwen: tagwlimt taceɛlalt talemmast',
    '🤘🏽' => 'azamul n wacciwen: taglimt talemmast',
    '🤘🏾' => 'azamul n wacciwen: taglimt tubrikt talemmast',
    '🤘🏿' => 'azamul n wacciwen: taglimt tubrikt',
    '🤙🏻' => 'afus n usiwel: taglimt taceɛlalt',
    '🤙🏼' => 'afus n usiwel: tagwlimt taceɛlalt talemmast',
    '🤙🏽' => 'afus n usiwel: taglimt talemmast',
    '🤙🏾' => 'afus n usiwel: taglimt tubrikt talemmast',
    '🤙🏿' => 'afus n usiwel: taglimt tubrikt',
    '👈🏻' => 'afus s udebbuz yerran s azelmaḍ: taglimt taceɛlalt',
    '👈🏼' => 'afus s udebbuz yerran s azelmaḍ: tagwlimt taceɛlalt talemmast',
    '👈🏽' => 'afus s udebbuz yerran s azelmaḍ: taglimt talemmast',
    '👈🏾' => 'afus s udebbuz yerran s azelmaḍ: taglimt tubrikt talemmast',
    '👈🏿' => 'afus s udebbuz yerran s azelmaḍ: taglimt tubrikt',
    '👉🏻' => 'afus s udebbuz yerran s ayeffus: taglimt taceɛlalt',
    '👉🏼' => 'afus s udebbuz yerran s ayeffus: tagwlimt taceɛlalt talemmast',
    '👉🏽' => 'afus s udebbuz yerran s ayeffus: taglimt talemmast',
    '👉🏾' => 'afus s udebbuz yerran s ayeffus: taglimt tubrikt talemmast',
    '👉🏿' => 'afus s udebbuz yerran s ayeffus: taglimt tubrikt',
    '👆🏻' => 'afus s udebbuz yerran d asawen: taglimt taceɛlalt',
    '👆🏼' => 'afus s udebbuz yerran d asawen: tagwlimt taceɛlalt talemmast',
    '👆🏽' => 'afus s udebbuz yerran d asawen: taglimt talemmast',
    '👆🏾' => 'afus s udebbuz yerran d asawen: taglimt tubrikt talemmast',
    '👆🏿' => 'afus s udebbuz yerran d asawen: taglimt tubrikt',
    '🖕🏻' => 'aḍad alemmas: taglimt taceɛlalt',
    '🖕🏼' => 'aḍad alemmas: tagwlimt taceɛlalt talemmast',
    '🖕🏽' => 'aḍad alemmas: taglimt talemmast',
    '🖕🏾' => 'aḍad alemmas: taglimt tubrikt talemmast',
    '🖕🏿' => 'aḍad alemmas: taglimt tubrikt',
    '👇🏻' => 'afus s udebbuz yerran d akesser: taglimt taceɛlalt',
    '👇🏼' => 'afus s udebbuz yerran d akesser: tagwlimt taceɛlalt talemmast',
    '👇🏽' => 'afus s udebbuz yerran d akesser: taglimt talemmast',
    '👇🏾' => 'afus s udebbuz yerran d akesser: taglimt tubrikt talemmast',
    '👇🏿' => 'afus s udebbuz yerran d akesser: taglimt tubrikt',
    '☝🏻' => 'ccahed yerran d asawen: taglimt taceɛlalt',
    '☝🏼' => 'ccahed yerran d asawen: tagwlimt taceɛlalt talemmast',
    '☝🏽' => 'ccahed yerran d asawen: taglimt talemmast',
    '☝🏾' => 'ccahed yerran d asawen: taglimt tubrikt talemmast',
    '☝🏿' => 'ccahed yerran d asawen: taglimt tubrikt',
    '🫵🏻' => 'ccahed iwehhan ɣer useqdac: taglimt taceɛlalt',
    '🫵🏼' => 'ccahed iwehhan ɣer useqdac: tagwlimt taceɛlalt talemmast',
    '🫵🏽' => 'ccahed iwehhan ɣer useqdac: taglimt talemmast',
    '🫵🏾' => 'ccahed iwehhan ɣer useqdac: taglimt tubrikt talemmast',
    '🫵🏿' => 'ccahed iwehhan ɣer useqdac: taglimt tubrikt',
    '👍🏻' => 'adebbuz d asawen: taglimt taceɛlalt',
    '👍🏼' => 'adebbuz d asawen: tagwlimt taceɛlalt talemmast',
    '👍🏽' => 'adebbuz d asawen: taglimt talemmast',
    '👍🏾' => 'adebbuz d asawen: taglimt tubrikt talemmast',
    '👍🏿' => 'adebbuz d asawen: taglimt tubrikt',
    '👎🏻' => 'adebbuz d akessar: taglimt taceɛlalt',
    '👎🏼' => 'adebbuz d akessar: tagwlimt taceɛlalt talemmast',
    '👎🏽' => 'adebbuz d akessar: taglimt talemmast',
    '👎🏾' => 'adebbuz d akessar: taglimt tubrikt talemmast',
    '👎🏿' => 'adebbuz d akessar: taglimt tubrikt',
    '✊🏻' => 'arfad n ufus ikersen: taglimt taceɛlalt',
    '✊🏼' => 'arfad n ufus ikersen: tagwlimt taceɛlalt talemmast',
    '✊🏽' => 'arfad n ufus ikersen: taglimt talemmast',
    '✊🏾' => 'arfad n ufus ikersen: taglimt tubrikt talemmast',
    '✊🏿' => 'arfad n ufus ikersen: taglimt tubrikt',
    '👊🏻' => 'awwaḍ n lbunya: taglimt taceɛlalt',
    '👊🏼' => 'awwaḍ n lbunya: tagwlimt taceɛlalt talemmast',
    '👊🏽' => 'awwaḍ n lbunya: taglimt talemmast',
    '👊🏾' => 'awwaḍ n lbunya: taglimt tubrikt talemmast',
    '👊🏿' => 'awwaḍ n lbunya: taglimt tubrikt',
    '🤛🏻' => 'afus ikersen ɣer uzelmaḍ: taglimt taceɛlalt',
    '🤛🏼' => 'afus ikersen ɣer uzelmaḍ: tagwlimt taceɛlalt talemmast',
    '🤛🏽' => 'afus ikersen ɣer uzelmaḍ: taglimt talemmast',
    '🤛🏾' => 'afus ikersen ɣer uzelmaḍ: taglimt tubrikt talemmast',
    '🤛🏿' => 'afus ikersen ɣer uzelmaḍ: taglimt tubrikt',
    '🤜🏻' => 'afus ikersen ɣer uyeffus: taglimt taceɛlalt',
    '🤜🏼' => 'afus ikersen ɣer uyeffus: tagwlimt taceɛlalt talemmast',
    '🤜🏽' => 'afus ikersen ɣer uyeffus: taglimt talemmast',
    '🤜🏾' => 'afus ikersen ɣer uyeffus: taglimt tubrikt talemmast',
    '🤜🏿' => 'afus ikersen ɣer uyeffus: taglimt tubrikt',
    '👏🏻' => 'aṣerfeq: taglimt taceɛlalt',
    '👏🏼' => 'aṣerfeq: tagwlimt taceɛlalt talemmast',
    '👏🏽' => 'aṣerfeq: taglimt talemmast',
    '👏🏾' => 'aṣerfeq: taglimt tubrikt talemmast',
    '👏🏿' => 'aṣerfeq: taglimt tubrikt',
    '🙌🏻' => 'ifassen yulin: taglimt taceɛlalt',
    '🙌🏼' => 'ifassen yulin: tagwlimt taceɛlalt talemmast',
    '🙌🏽' => 'ifassen yulin: taglimt talemmast',
    '🙌🏾' => 'ifassen yulin: taglimt tubrikt talemmast',
    '🙌🏿' => 'ifassen yulin: taglimt tubrikt',
    '🫶🏻' => 'ifassen am wul: taglimt taceɛlalt',
    '🫶🏼' => 'ifassen am wul: tagwlimt taceɛlalt talemmast',
    '🫶🏽' => 'ifassen am wul: taglimt talemmast',
    '🫶🏾' => 'ifassen am wul: taglimt tubrikt talemmast',
    '🫶🏿' => 'ifassen am wul: taglimt tubrikt',
    '👐🏻' => 'ifassen yeldin: taglimt taceɛlalt',
    '👐🏼' => 'ifassen yeldin: tagwlimt taceɛlalt talemmast',
    '👐🏽' => 'ifassen yeldin: taglimt talemmast',
    '👐🏾' => 'ifassen yeldin: taglimt tubrikt talemmast',
    '👐🏿' => 'ifassen yeldin: taglimt tubrikt',
    '🤲🏻' => 'tidikal yeddukklen d asawen: taglimt taceɛlalt',
    '🤲🏼' => 'tidikal yeddukklen d asawen: tagwlimt taceɛlalt talemmast',
    '🤲🏽' => 'tidikal yeddukklen d asawen: taglimt talemmast',
    '🤲🏾' => 'tidikal yeddukklen d asawen: taglimt tubrikt talemmast',
    '🤲🏿' => 'tidikal yeddukklen d asawen: taglimt tubrikt',
    '🤝🏻' => 'amsalem: taglimt taceɛlalt',
    '🤝🏼' => 'amsalem: tagwlimt taceɛlalt talemmast',
    '🤝🏽' => 'amsalem: taglimt talemmast',
    '🤝🏾' => 'amsalem: taglimt tubrikt talemmast',
    '🤝🏿' => 'amsalem: taglimt tubrikt',
    '🙏🏻' => 'ifassen ineṭḍen: taglimt taceɛlalt',
    '🙏🏼' => 'ifassen ineṭḍen: tagwlimt taceɛlalt talemmast',
    '🙏🏽' => 'ifassen ineṭḍen: taglimt talemmast',
    '🙏🏾' => 'ifassen ineṭḍen: taglimt tubrikt talemmast',
    '🙏🏿' => 'ifassen ineṭḍen: taglimt tubrikt',
    '✍🏻' => 'afus yettarun: taglimt taceɛlalt',
    '✍🏼' => 'afus yettarun: tagwlimt taceɛlalt talemmast',
    '✍🏽' => 'afus yettarun: taglimt talemmast',
    '✍🏾' => 'afus yettarun: taglimt tubrikt talemmast',
    '✍🏿' => 'afus yettarun: taglimt tubrikt',
    '💅🏻' => 'iɣmi n waccaren: taglimt taceɛlalt',
    '💅🏼' => 'iɣmi n waccaren: tagwlimt taceɛlalt talemmast',
    '💅🏽' => 'iɣmi n waccaren: taglimt talemmast',
    '💅🏾' => 'iɣmi n waccaren: taglimt tubrikt talemmast',
    '💅🏿' => 'iɣmi n waccaren: taglimt tubrikt',
    '🤳🏻' => 'asilfi: taglimt taceɛlalt',
    '🤳🏼' => 'asilfi: tagwlimt taceɛlalt talemmast',
    '🤳🏽' => 'asilfi: taglimt talemmast',
    '🤳🏾' => 'asilfi: taglimt tubrikt talemmast',
    '🤳🏿' => 'asilfi: taglimt tubrikt',
    '💪🏻' => 'akras n lbunya: taglimt taceɛlalt',
    '💪🏼' => 'akras n lbunya: tagwlimt taceɛlalt talemmast',
    '💪🏽' => 'akras n lbunya: taglimt talemmast',
    '💪🏾' => 'akras n lbunya: taglimt tubrikt talemmast',
    '💪🏿' => 'akras n lbunya: taglimt tubrikt',
    '🦵🏻' => 'aqejjir: taglimt taceɛlalt',
    '🦵🏼' => 'aqejjir: tagwlimt taceɛlalt talemmast',
    '🦵🏽' => 'aqejjir: taglimt talemmast',
    '🦵🏾' => 'aqejjir: taglimt tubrikt talemmast',
    '🦵🏿' => 'aqejjir: taglimt tubrikt',
    '🦶🏻' => 'aḍar: taglimt taceɛlalt',
    '🦶🏼' => 'aḍar: tagwlimt taceɛlalt talemmast',
    '🦶🏽' => 'aḍar: taglimt talemmast',
    '🦶🏾' => 'aḍar: taglimt tubrikt talemmast',
    '🦶🏿' => 'aḍar: taglimt tubrikt',
    '👂🏻' => 'ameẓẓuɣ: taglimt taceɛlalt',
    '👂🏼' => 'ameẓẓuɣ: tagwlimt taceɛlalt talemmast',
    '👂🏽' => 'ameẓẓuɣ: taglimt talemmast',
    '👂🏾' => 'ameẓẓuɣ: taglimt tubrikt talemmast',
    '👂🏿' => 'ameẓẓuɣ: taglimt tubrikt',
    '🦻🏻' => 'ameẓẓuɣ s ufecku n tmesliwt: taglimt taceɛlalt',
    '🦻🏼' => 'ameẓẓuɣ s ufecku n tmesliwt: tagwlimt taceɛlalt talemmast',
    '🦻🏽' => 'ameẓẓuɣ s ufecku n tmesliwt: taglimt talemmast',
    '🦻🏾' => 'ameẓẓuɣ s ufecku n tmesliwt: taglimt tubrikt talemmast',
    '🦻🏿' => 'ameẓẓuɣ s ufecku n tmesliwt: taglimt tubrikt',
    '👃🏻' => 'anzaren: taglimt taceɛlalt',
    '👃🏼' => 'anzaren: tagwlimt taceɛlalt talemmast',
    '👃🏽' => 'anzaren: taglimt talemmast',
    '👃🏾' => 'anzaren: taglimt tubrikt talemmast',
    '👃🏿' => 'anzaren: taglimt tubrikt',
    '👶🏻' => 'aṭufan: taglimt taceɛlalt',
    '👶🏼' => 'aṭufan: tagwlimt taceɛlalt talemmast',
    '👶🏽' => 'aṭufan: taglimt talemmast',
    '👶🏾' => 'aṭufan: taglimt tubrikt talemmast',
    '👶🏿' => 'aṭufan: taglimt tubrikt',
    '🧒🏻' => 'agrud: taglimt taceɛlalt',
    '🧒🏼' => 'agrud: tagwlimt taceɛlalt talemmast',
    '🧒🏽' => 'agrud: taglimt talemmast',
    '🧒🏾' => 'agrud: taglimt tubrikt talemmast',
    '🧒🏿' => 'agrud: taglimt tubrikt',
    '👦🏻' => 'aqcic: taglimt taceɛlalt',
    '👦🏼' => 'aqcic: tagwlimt taceɛlalt talemmast',
    '👦🏽' => 'aqcic: taglimt talemmast',
    '👦🏾' => 'aqcic: taglimt tubrikt talemmast',
    '👦🏿' => 'aqcic: taglimt tubrikt',
    '👧🏻' => 'taqcict: taglimt taceɛlalt',
    '👧🏼' => 'taqcict: tagwlimt taceɛlalt talemmast',
    '👧🏽' => 'taqcict: taglimt talemmast',
    '👧🏾' => 'taqcict: taglimt tubrikt talemmast',
    '👧🏿' => 'taqcict: taglimt tubrikt',
    '🧑🏻' => 'amdan: taglimt taceɛlalt',
    '🧑🏼' => 'amdan: tagwlimt taceɛlalt talemmast',
    '🧑🏽' => 'amdan: taglimt talemmast',
    '🧑🏾' => 'amdan: taglimt tubrikt talemmast',
    '🧑🏿' => 'amdan: taglimt tubrikt',
    '👱🏻' => 'amdan: taglimt taceɛlalt, acekkuḥ aceɛlal',
    '👱🏼' => 'amdan: tagwlimt taceɛlalt talemmast, acekkuḥ aceɛlal',
    '👱🏽' => 'amdan: taglimt talemmast, acekkuḥ aceɛlal',
    '👱🏾' => 'amdan: taglimt tubrikt talemmast, acekkuḥ aceɛlal',
    '👱🏿' => 'amdan: taglimt tubrikt, acekkuḥ aceɛlal',
    '👨🏻' => 'argaz: taglimt taceɛlalt',
    '👨🏼' => 'argaz: tagwlimt taceɛlalt talemmast',
    '👨🏽' => 'argaz: taglimt talemmast',
    '👨🏾' => 'argaz: taglimt tubrikt talemmast',
    '👨🏿' => 'argaz: taglimt tubrikt',
    '🧔🏻' => 'amdan: taglimt taceɛlalt, tamart',
    '🧔🏼' => 'amdan: tagwlimt taceɛlalt talemmast, tamart',
    '🧔🏽' => 'amdan: taglimt talemmast, tamart',
    '🧔🏾' => 'amdan: taglimt tubrikt talemmast, tamart',
    '🧔🏿' => 'amdan: taglimt tubrikt, tamart',
    '👩🏻' => 'tameṭṭut: taglimt taceɛlalt',
    '👩🏼' => 'tameṭṭut: tagwlimt taceɛlalt talemmast',
    '👩🏽' => 'tameṭṭut: taglimt talemmast',
    '👩🏾' => 'tameṭṭut: taglimt tubrikt talemmast',
    '👩🏿' => 'tameṭṭut: taglimt tubrikt',
    '🧓🏻' => 'amdan meqqren: taglimt taceɛlalt',
    '🧓🏼' => 'amdan meqqren: tagwlimt taceɛlalt talemmast',
    '🧓🏽' => 'amdan meqqren: taglimt talemmast',
    '🧓🏾' => 'amdan meqqren: taglimt tubrikt talemmast',
    '🧓🏿' => 'amdan meqqren: taglimt tubrikt',
    '👴🏻' => 'amɣar: taglimt taceɛlalt',
    '👴🏼' => 'amɣar: tagwlimt taceɛlalt talemmast',
    '👴🏽' => 'amɣar: taglimt talemmast',
    '👴🏾' => 'amɣar: taglimt tubrikt talemmast',
    '👴🏿' => 'amɣar: taglimt tubrikt',
    '👵🏻' => 'tamɣart: taglimt taceɛlalt',
    '👵🏼' => 'tamɣart: tagwlimt taceɛlalt talemmast',
    '👵🏽' => 'tamɣart: taglimt talemmast',
    '👵🏾' => 'tamɣart: taglimt tubrikt talemmast',
    '👵🏿' => 'tamɣart: taglimt tubrikt',
    '🙍🏻' => 'amdan imexenfeṛ: taglimt taceɛlalt',
    '🙍🏼' => 'amdan imexenfeṛ: tagwlimt taceɛlalt talemmast',
    '🙍🏽' => 'amdan imexenfeṛ: taglimt talemmast',
    '🙍🏾' => 'amdan imexenfeṛ: taglimt tubrikt talemmast',
    '🙍🏿' => 'amdan imexenfeṛ: taglimt tubrikt',
    '🙎🏻' => 'amdan imcennef: taglimt taceɛlalt',
    '🙎🏼' => 'amdan imcennef: tagwlimt taceɛlalt talemmast',
    '🙎🏽' => 'amdan imcennef: taglimt talemmast',
    '🙎🏾' => 'amdan imcennef: taglimt tubrikt talemmast',
    '🙎🏿' => 'amdan imcennef: taglimt tubrikt',
    '🧏🏻' => 'amdan aɛeẓẓug: taglimt taceɛlalt',
    '🧏🏼' => 'amdan aɛeẓẓug: tagwlimt taceɛlalt talemmast',
    '🧏🏽' => 'amdan aɛeẓẓug: taglimt talemmast',
    '🧏🏾' => 'amdan aɛeẓẓug: taglimt tubrikt talemmast',
    '🧏🏿' => 'amdan aɛeẓẓug: taglimt tubrikt',
    '🙇🏻' => 'amdan yettanez: taglimt taceɛlalt',
    '🙇🏼' => 'amdan yettanez: tagwlimt taceɛlalt talemmast',
    '🙇🏽' => 'amdan yettanez: taglimt talemmast',
    '🙇🏾' => 'amdan yettanez: taglimt tubrikt talemmast',
    '🙇🏿' => 'amdan yettanez: taglimt tubrikt',
    '👮🏻' => 'amsaltu: taglimt taceɛlalt',
    '👮🏼' => 'amsaltu: tagwlimt taceɛlalt talemmast',
    '👮🏽' => 'amsaltu: taglimt talemmast',
    '👮🏾' => 'amsaltu: taglimt tubrikt talemmast',
    '👮🏿' => 'amsaltu: taglimt tubrikt',
    '💂🏻' => 'aɛessas: taglimt taceɛlalt',
    '💂🏼' => 'aɛessas: tagwlimt taceɛlalt talemmast',
    '💂🏽' => 'aɛessas: taglimt talemmast',
    '💂🏾' => 'aɛessas: taglimt tubrikt talemmast',
    '💂🏿' => 'aɛessas: taglimt tubrikt',
    '🥷🏻' => 'aninja: taglimt taceɛlalt',
    '🥷🏼' => 'aninja: tagwlimt taceɛlalt talemmast',
    '🥷🏽' => 'aninja: taglimt talemmast',
    '🥷🏾' => 'aninja: taglimt tubrikt talemmast',
    '🥷🏿' => 'aninja: taglimt tubrikt',
    '🤴🏻' => 'ageldun: taglimt taceɛlalt',
    '🤴🏼' => 'ageldun: tagwlimt taceɛlalt talemmast',
    '🤴🏽' => 'ageldun: taglimt talemmast',
    '🤴🏾' => 'ageldun: taglimt tubrikt talemmast',
    '🤴🏿' => 'ageldun: taglimt tubrikt',
    '👸🏻' => 'tageldunt: taglimt taceɛlalt',
    '👸🏼' => 'tageldunt: tagwlimt taceɛlalt talemmast',
    '👸🏽' => 'tageldunt: taglimt talemmast',
    '👸🏾' => 'tageldunt: taglimt tubrikt talemmast',
    '👸🏿' => 'tageldunt: taglimt tubrikt',
    '👳🏻' => 'amdan s uɛessab: taglimt taceɛlalt',
    '👳🏼' => 'amdan s uɛessab: tagwlimt taceɛlalt talemmast',
    '👳🏽' => 'amdan s uɛessab: taglimt talemmast',
    '👳🏾' => 'amdan s uɛessab: taglimt tubrikt talemmast',
    '👳🏿' => 'amdan s uɛessab: taglimt tubrikt',
    '🤰🏻' => 'tameṭṭut s tadist: taglimt taceɛlalt',
    '🤰🏼' => 'tameṭṭut s tadist: tagwlimt taceɛlalt talemmast',
    '🤰🏽' => 'tameṭṭut s tadist: taglimt talemmast',
    '🤰🏾' => 'tameṭṭut s tadist: taglimt tubrikt talemmast',
    '🤰🏿' => 'tameṭṭut s tadist: taglimt tubrikt',
    '🫃🏻' => 'argaz s tadist: taglimt taceɛlalt',
    '🫃🏼' => 'argaz s tadist: tagwlimt taceɛlalt talemmast',
    '🫃🏽' => 'argaz s tadist: taglimt talemmast',
    '🫃🏾' => 'argaz s tadist: taglimt tubrikt talemmast',
    '🫃🏿' => 'argaz s tadist: taglimt tubrikt',
    '🫄🏻' => 'amdan s tawist: taglimt taceɛlalt',
    '🫄🏼' => 'amdan s tawist: tagwlimt taceɛlalt talemmast',
    '🫄🏽' => 'amdan s tawist: taglimt talemmast',
    '🫄🏾' => 'amdan s tawist: taglimt tubrikt talemmast',
    '🫄🏿' => 'amdan s tawist: taglimt tubrikt',
    '👼🏻' => 'aṭufan aneglus: taglimt taceɛlalt',
    '👼🏼' => 'aṭufan aneglus: tagwlimt taceɛlalt talemmast',
    '👼🏽' => 'aṭufan aneglus: taglimt talemmast',
    '👼🏾' => 'aṭufan aneglus: taglimt tubrikt talemmast',
    '👼🏿' => 'aṭufan aneglus: taglimt tubrikt',
    '🚶🏻' => 'amdan ileḥḥun: taglimt taceɛlalt',
    '🚶🏼' => 'amdan ileḥḥun: tagwlimt taceɛlalt talemmast',
    '🚶🏽' => 'amdan ileḥḥun: taglimt talemmast',
    '🚶🏾' => 'amdan ileḥḥun: taglimt tubrikt talemmast',
    '🚶🏿' => 'amdan ileḥḥun: taglimt tubrikt',
    '🧍🏻' => 'amdan ibedden: taglimt taceɛlalt',
    '🧍🏼' => 'amdan ibedden: tagwlimt taceɛlalt talemmast',
    '🧍🏽' => 'amdan ibedden: taglimt talemmast',
    '🧍🏾' => 'amdan ibedden: taglimt tubrikt talemmast',
    '🧍🏿' => 'amdan ibedden: taglimt tubrikt',
    '🧎🏻' => 'amdan ɣef tgecrar: taglimt taceɛlalt',
    '🧎🏼' => 'amdan ɣef tgecrar: tagwlimt taceɛlalt talemmast',
    '🧎🏽' => 'amdan ɣef tgecrar: taglimt talemmast',
    '🧎🏾' => 'amdan ɣef tgecrar: taglimt tubrikt talemmast',
    '🧎🏿' => 'amdan ɣef tgecrar: taglimt tubrikt',
    '🏃🏻' => 'amdan yettazzalen: taglimt taceɛlalt',
    '🏃🏼' => 'amdan yettazzalen: tagwlimt taceɛlalt talemmast',
    '🏃🏽' => 'amdan yettazzalen: taglimt talemmast',
    '🏃🏾' => 'amdan yettazzalen: taglimt tubrikt talemmast',
    '🏃🏿' => 'amdan yettazzalen: taglimt tubrikt',
    '💃🏻' => 'tameṭṭut iceṭṭḥen: taglimt taceɛlalt',
    '💃🏼' => 'tameṭṭut iceṭṭḥen: tagwlimt taceɛlalt talemmast',
    '💃🏽' => 'tameṭṭut iceṭṭḥen: taglimt talemmast',
    '💃🏾' => 'tameṭṭut iceṭṭḥen: taglimt tubrikt talemmast',
    '💃🏿' => 'tameṭṭut iceṭṭḥen: taglimt tubrikt',
    '🕺🏻' => 'argaz iceṭṭḥen: taglimt taceɛlalt',
    '🕺🏼' => 'argaz iceṭṭḥen: tagwlimt taceɛlalt talemmast',
    '🕺🏽' => 'argaz iceṭṭḥen: taglimt talemmast',
    '🕺🏾' => 'argaz iceṭṭḥen: taglimt tubrikt talemmast',
    '🕺🏿' => 'argaz iceṭṭḥen: taglimt tubrikt',
    '👯🏻' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt taceɛlalt',
    '👯🏼' => 'imdanen s yimeẓẓuɣen n yiwtal: tagwlimt taceɛlalt talemmast',
    '👯🏽' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt talemmast',
    '👯🏾' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt talemmast',
    '👯🏿' => 'imdanen s yimeẓẓuɣen n yiwtal: taglimt tubrikt',
    '🚴🏻' => 'amdan s uvilu: taglimt taceɛlalt',
    '🚴🏼' => 'amdan s uvilu: tagwlimt taceɛlalt talemmast',
    '🚴🏽' => 'amdan s uvilu: taglimt talemmast',
    '🚴🏾' => 'amdan s uvilu: taglimt tubrikt talemmast',
    '🚴🏿' => 'amdan s uvilu: taglimt tubrikt',
    '🤽🏻' => 'amdan yetturare water polo: taglimt taceɛlalt',
    '🤽🏼' => 'amdan yetturare water polo: tagwlimt taceɛlalt talemmast',
    '🤽🏽' => 'amdan yetturare water polo: taglimt talemmast',
    '🤽🏾' => 'amdan yetturare water polo: taglimt tubrikt talemmast',
    '🤽🏿' => 'amdan yetturare water polo: taglimt tubrikt',
    '🤾🏻' => 'amdan yetturaren ddabex n ufus: taglimt taceɛlalt',
    '🤾🏼' => 'amdan yetturaren ddabex n ufus: tagwlimt taceɛlalt talemmast',
    '🤾🏽' => 'amdan yetturaren ddabex n ufus: taglimt talemmast',
    '🤾🏾' => 'amdan yetturaren ddabex n ufus: taglimt tubrikt talemmast',
    '🤾🏿' => 'amdan yetturaren ddabex n ufus: taglimt tubrikt',
    '🛀🏻' => 'amdan yeccucufen: taglimt taceɛlalt',
    '🛀🏼' => 'amdan yeccucufen: tagwlimt taceɛlalt talemmast',
    '🛀🏽' => 'amdan yeccucufen: taglimt talemmast',
    '🛀🏾' => 'amdan yeccucufen: taglimt tubrikt talemmast',
    '🛀🏿' => 'amdan yeccucufen: taglimt tubrikt',
    '🛌🏻' => 'amdan deg wusu: taglimt taceɛlalt',
    '🛌🏼' => 'amdan deg wusu: tagwlimt taceɛlalt talemmast',
    '🛌🏽' => 'amdan deg wusu: taglimt talemmast',
    '🛌🏾' => 'amdan deg wusu: taglimt tubrikt talemmast',
    '🛌🏿' => 'amdan deg wusu: taglimt tubrikt',
    '👭🏻' => 'tulawin myuṭṭafent ifassen: taglimt taceɛlalt',
    '👭🏼' => 'tulawin myuṭṭafent ifassen: tagwlimt taceɛlalt talemmast',
    '👭🏽' => 'tulawin myuṭṭafent ifassen: taglimt talemmast',
    '👭🏾' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt talemmast',
    '👭🏿' => 'tulawin myuṭṭafent ifassen: taglimt tubrikt',
    '👫🏻' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt taceɛlalt',
    '👫🏼' => 'tameṭṭut d urgaz myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast',
    '👫🏽' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt talemmast',
    '👫🏾' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt talemmast',
    '👫🏿' => 'tameṭṭut d urgaz myuṭṭafen ifassen: taglimt tubrikt',
    '👬🏻' => 'irgazen myuṭṭafen ifassen: taglimt taceɛlalt',
    '👬🏼' => 'irgazen myuṭṭafen ifassen: tagwlimt taceɛlalt talemmast',
    '👬🏽' => 'irgazen myuṭṭafen ifassen: taglimt talemmast',
    '👬🏾' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt talemmast',
    '👬🏿' => 'irgazen myuṭṭafen ifassen: taglimt tubrikt',
    '💑🏻' => 'tayuga s wul: taglimt taceɛlalt',
    '💑🏼' => 'tayuga s wul: tagwlimt taceɛlalt talemmast',
    '💑🏽' => 'tayuga s wul: taglimt talemmast',
    '💑🏾' => 'tayuga s wul: taglimt tubrikt talemmast',
    '💑🏿' => 'tayuga s wul: taglimt tubrikt',
    '🇦🇨' => 'anay: Tigzirt n Aṣunsyun',
    '🇦🇩' => 'anay: Undura',
    '🇦🇪' => 'anay: Tigeldunin Yedduklen Taɛrabin',
    '🇦🇫' => 'anay: Afɣanistan',
    '🇦🇬' => 'anay: Untiga d Barbuda',
    '🇦🇮' => 'anay: Ungiya',
    '🇦🇱' => 'anay: Lalbani',
    '🇦🇲' => 'anay: Arminya',
    '🇦🇴' => 'anay: Ungula',
    '🇦🇶' => 'anay: Anṭarktik',
    '🇦🇷' => 'anay: Arjuntin',
    '🇦🇸' => 'anay: Samwa Tamarikanit',
    '🇦🇹' => 'anay: Ustriya',
    '🇦🇺' => 'anay: Ustrali',
    '🇦🇼' => 'anay: Aruba',
    '🇦🇽' => 'anay: Tigzirin n Aland',
    '🇦🇿' => 'anay: Azrabijan',
    '🇧🇦' => 'anay: Busna d Hersek',
    '🇧🇧' => 'anay: Barbadus',
    '🇧🇩' => 'anay: Bangladac',
    '🇧🇪' => 'anay: Belǧik',
    '🇧🇫' => 'anay: Burkina Fasu',
    '🇧🇬' => 'anay: Bulgari',
    '🇧🇭' => 'anay: Baḥrin',
    '🇧🇮' => 'anay: Burandi',
    '🇧🇯' => 'anay: Binin',
    '🇧🇱' => 'anay: Sant Baṛtilimi',
    '🇧🇲' => 'anay: Bermuda',
    '🇧🇳' => 'anay: Bruney',
    '🇧🇴' => 'anay: Bulivi',
    '🇧🇶' => 'anay: Huland n Kaṛayib',
    '🇧🇷' => 'anay: Brizil',
    '🇧🇸' => 'anay: Bahamas',
    '🇧🇹' => 'anay: Bhutan',
    '🇧🇻' => 'anay: Tigzirin n Buvet',
    '🇧🇼' => 'anay: Bustwana',
    '🇧🇾' => 'anay: Bilarus',
    '🇧🇿' => 'anay: Biliz',
    '🇨🇦' => 'anay: Kanada',
    '🇨🇨' => 'anay: Tigzirin n Kukus',
    '🇨🇩' => 'anay: Tigduda Tagdudant n Kungu',
    '🇨🇫' => 'anay: Tigduda n Tefriqt Talemmast',
    '🇨🇬' => 'anay: Kungu',
    '🇨🇭' => 'anay: Swis',
    '🇨🇮' => 'anay: Kuṭ Divwar',
    '🇨🇰' => 'anay: Tigzirin n Kuk',
    '🇨🇱' => 'anay: Cili',
    '🇨🇲' => 'anay: Kamirun',
    '🇨🇳' => 'anay: Lacin',
    '🇨🇴' => 'anay: Kulumbi',
    '🇨🇵' => 'anay: Tigzirt n Klipirṭun',
    '🇨🇷' => 'anay: Kusta Rika',
    '🇨🇺' => 'anay: Kuba',
    '🇨🇻' => 'anay: Tigzirin n yixef azegzaw',
    '🇨🇼' => 'anay: Kurasaw',
    '🇨🇽' => 'anay: Tigzrin n Kristmaṣ',
    '🇨🇾' => 'anay: Cipr',
    '🇨🇿' => 'anay: Čček',
    '🇩🇪' => 'anay: Lalman',
    '🇩🇬' => 'anay: Dyigu Garsiya',
    '🇩🇯' => 'anay: Ǧibuti',
    '🇩🇰' => 'anay: Denmark',
    '🇩🇲' => 'anay: Duminik',
    '🇩🇴' => 'anay: Tigduda Taduminikit',
    '🇩🇿' => 'anay: Lezzayer',
    '🇪🇦' => 'anay: Sebta d Melilla',
    '🇪🇨' => 'anay: Ikwaṭur',
    '🇪🇪' => 'anay: Istunya',
    '🇪🇬' => 'anay: Maṣr',
    '🇪🇭' => 'anay: Seḥra n umalu',
    '🇪🇷' => 'anay: Iritiria',
    '🇪🇸' => 'anay: Spanya',
    '🇪🇹' => 'anay: Utyupi',
    '🇪🇺' => 'anay: Tiddukkla n Turuft',
    '🇫🇮' => 'anay: Finlund',
    '🇫🇯' => 'anay: Fiji',
    '🇫🇰' => 'anay: Tigzirin n Falkland',
    '🇫🇲' => 'anay: Mikrunizya',
    '🇫🇴' => 'anay: Tigzirin n Faṛwi',
    '🇫🇷' => 'anay: Fransa',
    '🇬🇦' => 'anay: Gabun',
    '🇬🇧' => 'anay: Tagelda Yedduklen',
    '🇬🇩' => 'anay: Grunad',
    '🇬🇪' => 'anay: Jiyurji',
    '🇬🇫' => 'anay: Ɣana tafransist',
    '🇬🇬' => 'anay: Girnizi',
    '🇬🇭' => 'anay: Ɣana',
    '🇬🇮' => 'anay: Jibraltar',
    '🇬🇱' => 'anay: Grunland',
    '🇬🇲' => 'anay: Gambya',
    '🇬🇳' => 'anay: Ɣinya',
    '🇬🇵' => 'anay: Gwadalupi',
    '🇬🇶' => 'anay: Ɣinya Tasebgast',
    '🇬🇷' => 'anay: Lagris',
    '🇬🇸' => 'anay: Tigzirin n Jyuṛjya n Unẓul akked Sandwič n Unẓul',
    '🇬🇹' => 'anay: Gwatimala',
    '🇬🇺' => 'anay: Gwam',
    '🇬🇼' => 'anay: Ɣinya-Bisaw',
    '🇬🇾' => 'anay: Guwana',
    '🇭🇰' => 'anay: Tamnaṭ Taqbuṛt Tacinwat n Hung Kung',
    '🇭🇲' => 'anay: Tigzirin n Hird d Makdunalt',
    '🇭🇳' => 'anay: Hunduras',
    '🇭🇷' => 'anay: Kerwasya',
    '🇭🇹' => 'anay: Hayti',
    '🇭🇺' => 'anay: Hungri',
    '🇮🇨' => 'anay: Tigzirin Tikanaṛiyin',
    '🇮🇩' => 'anay: Indunizi',
    '🇮🇪' => 'anay: Lirlund',
    '🇮🇱' => 'anay: Izrayil',
    '🇮🇲' => 'anay: Tigzirt n Man',
    '🇮🇳' => 'anay: Lhend',
    '🇮🇴' => 'anay: Akal Aglizi deg Ugaraw Ahendi',
    '🇮🇶' => 'anay: Lɛiraq',
    '🇮🇷' => 'anay: Iran',
    '🇮🇸' => 'anay: Island',
    '🇮🇹' => 'anay: Ṭelyan',
    '🇯🇪' => 'anay: Jirzi',
    '🇯🇲' => 'anay: Jamyika',
    '🇯🇴' => 'anay: Lajurdani',
    '🇯🇵' => 'anay: Jappu',
    '🇰🇪' => 'anay: Kinya',
    '🇰🇬' => 'anay: Kirigistan',
    '🇰🇭' => 'anay: Cambudya',
    '🇰🇮' => 'anay: Kiribati',
    '🇰🇲' => 'anay: Kumur',
    '🇰🇳' => 'anay: San Kits d Nivis',
    '🇰🇵' => 'anay: Kurya, Ufella',
    '🇰🇷' => 'anay: Kurya, Wadda',
    '🇰🇼' => 'anay: Kuwayt',
    '🇰🇾' => 'anay: Tigzirin n Kamyan',
    '🇰🇿' => 'anay: Kazaxistan',
    '🇱🇦' => 'anay: Laws',
    '🇱🇧' => 'anay: Lubnan',
    '🇱🇨' => 'anay: San Lučya',
    '🇱🇮' => 'anay: Layctenstan',
    '🇱🇰' => 'anay: Sri Lanka',
    '🇱🇷' => 'anay: Libirya',
    '🇱🇸' => 'anay: Lizuṭu',
    '🇱🇹' => 'anay: Liṭwanya',
    '🇱🇺' => 'anay: Luksamburg',
    '🇱🇻' => 'anay: Latvia',
    '🇱🇾' => 'anay: Libya',
    '🇲🇦' => 'anay: Lmerruk',
    '🇲🇨' => 'anay: Munaku',
    '🇲🇩' => 'anay: Muldabi',
    '🇲🇪' => 'anay: Muntinigru',
    '🇲🇫' => 'anay: San Maṛtan',
    '🇲🇬' => 'anay: Madaɣecqer',
    '🇲🇭' => 'anay: Tigzirin n Marcal',
    '🇲🇰' => 'anay: Masidunya n ugafa',
    '🇲🇱' => 'anay: Mali',
    '🇲🇲' => 'anay: Myanmar',
    '🇲🇳' => 'anay: Mungulya',
    '🇲🇴' => 'anay: Tamnaḍt tudbilt tuzzigt tacinwat n Makaw',
    '🇲🇵' => 'anay: Tigzirin n Maryan Ufella',
    '🇲🇶' => 'anay: Martinik',
    '🇲🇷' => 'anay: Muriṭanya',
    '🇲🇸' => 'anay: Munsirat',
    '🇲🇹' => 'anay: Malṭ',
    '🇲🇺' => 'anay: Muris',
    '🇲🇻' => 'anay: Maldib',
    '🇲🇼' => 'anay: Malawi',
    '🇲🇽' => 'anay: Meksik',
    '🇲🇾' => 'anay: Malizya',
    '🇲🇿' => 'anay: Muzembiq',
    '🇳🇦' => 'anay: Namibya',
    '🇳🇨' => 'anay: Kalidunya Tamaynut',
    '🇳🇪' => 'anay: Nijer',
    '🇳🇫' => 'anay: Tigzirin Tinawfukin',
    '🇳🇬' => 'anay: Nijirya',
    '🇳🇮' => 'anay: Nikaragwa',
    '🇳🇱' => 'anay: Timura-Yessakesren',
    '🇳🇴' => 'anay: Nurvij',
    '🇳🇵' => 'anay: Nipal',
    '🇳🇷' => 'anay: Nuru',
    '🇳🇺' => 'anay: Niwi',
    '🇳🇿' => 'anay: Ziland Tamaynut',
    '🇴🇲' => 'anay: Ɛuman',
    '🇵🇦' => 'anay: Panam',
    '🇵🇪' => 'anay: Piru',
    '🇵🇫' => 'anay: Pulunizi tafransist',
    '🇵🇬' => 'anay: Ɣinya Tamaynut Tapaput',
    '🇵🇭' => 'anay: Filipin',
    '🇵🇰' => 'anay: Pakistan',
    '🇵🇱' => 'anay: Pulund',
    '🇵🇲' => 'anay: San Pyar d Miklun',
    '🇵🇳' => 'anay: Pitkarin',
    '🇵🇷' => 'anay: Purtu Riku',
    '🇵🇸' => 'anay: Falisṭin d Ɣezza',
    '🇵🇹' => 'anay: Purtugal',
    '🇵🇼' => 'anay: Palu',
    '🇵🇾' => 'anay: Paragway',
    '🇶🇦' => 'anay: Qaṭar',
    '🇷🇪' => 'anay: Timlilit',
    '🇷🇴' => 'anay: Rumani',
    '🇷🇸' => 'anay: Ṣirbya',
    '🇷🇺' => 'anay: Rrus',
    '🇷🇼' => 'anay: Ruwanda',
    '🇸🇦' => 'anay: Suɛudiya Taɛrabt',
    '🇸🇧' => 'anay: Tigzirin n Sulumun',
    '🇸🇨' => 'anay: Seycel',
    '🇸🇩' => 'anay: Sudan',
    '🇸🇪' => 'anay: Swid',
    '🇸🇬' => 'anay: Singafur',
    '🇸🇭' => 'anay: Sant Ilina',
    '🇸🇮' => 'anay: Sluvinya',
    '🇸🇯' => 'anay: Svalvard d Jan Mayen',
    '🇸🇰' => 'anay: Sluvakya',
    '🇸🇱' => 'anay: Sira Lyun',
    '🇸🇲' => 'anay: San Marinu',
    '🇸🇳' => 'anay: Sinigal',
    '🇸🇴' => 'anay: Ṣumal',
    '🇸🇷' => 'anay: Surinam',
    '🇸🇸' => 'anay: Sudan n unẓul',
    '🇸🇹' => 'anay: Saw Tumi d Pransip',
    '🇸🇻' => 'anay: Salvadur',
    '🇸🇽' => 'anay: Sint Maarten',
    '🇸🇾' => 'anay: Surya',
    '🇸🇿' => 'anay: Swazilund',
    '🇹🇦' => 'anay: Tristan da Kunha',
    '🇹🇨' => 'anay: Ṭurk d Tegzirin n Kaykus',
    '🇹🇩' => 'anay: Čad',
    '🇹🇫' => 'anay: Timura tifransisin n unẓul',
    '🇹🇬' => 'anay: Ṭugu',
    '🇹🇭' => 'anay: Ṭayland',
    '🇹🇯' => 'anay: Tajikistan',
    '🇹🇰' => 'anay: Ṭuklu',
    '🇹🇱' => 'anay: Tumur Asamar',
    '🇹🇲' => 'anay: Ṭurkmanistan',
    '🇹🇳' => 'anay: Tunes',
    '🇹🇴' => 'anay: Ṭunga',
    '🇹🇷' => 'anay: Ṭurk',
    '🇹🇹' => 'anay: Ṭrindad d Ṭubagu',
    '🇹🇻' => 'anay: Ṭuvalu',
    '🇹🇼' => 'anay: Ṭaywan',
    '🇹🇿' => 'anay: Ṭanzanya',
    '🇺🇦' => 'anay: Ukran',
    '🇺🇬' => 'anay: Uɣanda',
    '🇺🇲' => 'anay: Tigzirin ibeɛden n Marikan',
    '🇺🇳' => 'anay: Timura Iddukklen',
    '🇺🇸' => 'anay: WDM',
    '🇺🇾' => 'anay: Urugway',
    '🇺🇿' => 'anay: Uzbaxistan',
    '🇻🇦' => 'anay: Awanek n Vatikan',
    '🇻🇨' => 'anay: San Vansu d Grunadin',
    '🇻🇪' => 'anay: Venzwila',
    '🇻🇬' => 'anay: Tigzirin Tiverjiniyin Tigliziyin',
    '🇻🇮' => 'anay: W.D. Tigzirin n Virginya',
    '🇻🇳' => 'anay: Vyeṭnam',
    '🇻🇺' => 'anay: Vanwatu',
    '🇼🇫' => 'anay: Wallis d Futuna',
    '🇼🇸' => 'anay: Samwa',
    '🇽🇰' => 'anay: Kuṣuvu',
    '🇾🇪' => 'anay: Lyamen',
    '🇾🇹' => 'anay: Mayuṭ',
    '🇿🇦' => 'anay: Tafriqt Wadda',
    '🇿🇲' => 'anay: Zambya',
    '🇿🇼' => 'anay: Zimbabwi',
    '🏻' => 'taglimt taceɛlalt',
    '🏼' => 'tagwlimt taceɛlalt talemmast',
    '🏽' => 'taglimt talemmast',
    '🏾' => 'taglimt tubrikt talemmast',
    '🏿' => 'taglimt tubrikt',
    '😀' => 'acmumeḥ meqqren',
    '😃' => 'udem n ucmumeḥ s wallen yeldin',
    '😄' => 'acmumaḥ amesrar',
    '😁' => 'acmumeḥ n tuɣmas meṛṛa',
    '😆' => 'udem icmumḥen s yimi yeldin d wallen imedlen',
    '😅' => 'udem icmumḥen s leḥya',
    '🤣' => 'axbibeḍ deg lqaɛa seg teḍsa',
    '😂' => 'taḍsa almi i d-ɣlin imeṭṭawen',
    '🙂' => 'acmumeḥ afessas',
    '🙃' => 'udem yettin d akessar',
    '🫠' => 'udem yefsin',
    '😉' => 'udem s uɣmaz n tiṭ',
    '😊' => 'udem innecṛaḥen s wallen icmumḥen',
    '😇' => 'udem icmumḥen am lmalaykat',
    '🥰' => 'udem yecmumḥen s wulawen',
    '😍' => 'udem yecmumḥen s wallen am wulawen',
    '🤩' => 'udem yecmumḥen s wallen am yitran',
    '😘' => 'tasudent d wul',
    '😗' => 'tasudent',
    '☺' => 'udem n ucmumeḥ',
    '😚' => 'tasudent allen medlent',
    '😙' => 'tasudent meqqren',
    '🥲' => 'udem yecmumḥen s yimeṭṭawen',
    '😋' => 'udem yessibninen učči',
    '😛' => 'Udem s yiles',
    '😜' => 'Udem yessufɣen iles',
    '🤪' => 'udem yesseḍsayen',
    '😝' => 'udem ikemcen s yiles d-yeffɣen',
    '🤑' => 'udem s yidrimen',
    '🤗' => 'udem yefkan ahennec',
    '🤭' => 'udem s ufus ɣef yimi',
    '🫢' => 'udem s wallen yeldin d ufus ɣef yimi',
    '🫣' => 'udem s uɣummu n yiwet n tiṭ',
    '🤫' => 'udem asusam',
    '🤔' => 'udem yettxemmimen',
    '🫡' => 'udem yettwehhin',
    '🤐' => 'udem s yimi ixaḍen',
    '🤨' => 'udem s timmi irefden',
    '😐' => 'war awal',
    '😑' => 'udem war asenfali',
    '😶' => 'udem s war imi',
    '🫥' => 'udem s yizirig yettwagezmen',
    '😏' => 'acmumeḥ n tiḥḥerci',
    '😒' => 'udem isxenfṛen',
    '🙄' => 'udem s wallen ibellɣen',
    '😬' => 'udem yesmejgaren',
    '🤥' => 'udem yeskiddiben',
    '🫨' => 'udem yettergigin',
    '😌' => 'udem itheddnen',
    '😔' => 'udem isaḥen',
    '😪' => 'udem yeṭṭsen',
    '🤤' => 'udem yeslulduyen',
    '😴' => 'udem yennudmen',
    '🫩' => 'udem s tcullaḍ ddaw wallen',
    '😷' => 'udem s tekmamt',
    '🤒' => 'udem s utirmumitr',
    '🤕' => 'udem s cced ɣef uqerru',
    '🤢' => 'udem yettgarbaɛen',
    '🤮' => 'udem d-yettarran',
    '🤧' => 'udem yettaɛḍasen',
    '🥵' => 'udem yerɣan',
    '🥶' => 'udem asemmaḍ',
    '🥴' => 'udem yettargigin',
    '😵' => 'udem s wallen iwecmen',
    '🤯' => 'aqerru yetterḍqen',
    '🤠' => 'udem s tcacit',
    '🥳' => 'udem n lferḥ',
    '🥸' => 'udem yeffren',
    '😎' => 'acmumeḥ s nnwḍer n yiṭij',
    '🤓' => 'udem n lqari',
    '🧐' => 'udem s tiṭ yersan nwaḍer',
    '😕' => 'udem iεewqen',
    '🫤' => 'udem s yimi iɛewjen',
    '😟' => 'udem yuggaden',
    '🙁' => 'udem iruḥen ad isxenfeṛ',
    '☹' => 'udem amiglaz',
    '😮' => 'udem s yimi yeldin',
    '😯' => 'udem war taɣect',
    '😲' => 'udem iwehmen',
    '😳' => 'udem uzwiɣ',
    '🥺' => 'abaṛuṛec n wallen',
    '🥹' => 'udem yeṭṭfen imeṭṭawen',
    '😦' => 'udem yenneɣnan s yimi yeldin',
    '😧' => 'udem yesnuɣejfen',
    '😨' => 'udem iɣuylfen',
    '😰' => 'udem itqellqen yerna tidi',
    '😥' => 'udem iḥeznen maca yertaḥ',
    '😢' => 'udem yettrun',
    '😭' => 'yettexbibiḍ seg yimeṭṭawen',
    '😱' => 'udem yettsuɣun yugad',
    '😖' => 'udem iɛewqen',
    '😣' => 'udem akayay',
    '😞' => 'udem isremgen',
    '😓' => 'udem iḥznen, yettcercur d tidi',
    '😩' => 'udem yesxenfren',
    '😫' => 'udem yeɛyan',
    '🥱' => 'udem yettfan',
    '😤' => 'udem s wanzaren yettfuṛun',
    '😡' => 'udem izeɛfen',
    '😠' => 'udem yerfan',
    '🤬' => 'udem s yizamulen ɣef yimi',
    '😈' => 'udem yeḍsan s wacciwen',
    '👿' => 'udem yerfan s wacciwen',
    '💀' => 'aǧeɣǧuɣ',
    '☠' => 'aǧeɣǧuɣ d yiɣsan inmidagen',
    '💩' => 'azebbul n zbel',
    '🤡' => 'udem yennecraḥen',
    '👹' => 'waɣzen',
    '👺' => 'cciṭan',
    '👻' => 'afunṭum',
    '🤖' => 'aṛubut',
    '😺' => 'amcic yeḍsan',
    '😸' => 'amcic yeḍsan s wallen yeḍsan',
    '😹' => 'amcic s yimeṭṭawen n lferḥ',
    '😻' => 'amcic yecmumḥen s wallen d ulawen',
    '😼' => 'amcic s teḍsa n ukellex',
    '😽' => 'tasudent n umcic',
    '🙀' => 'amcic yeɛyan',
    '😿' => 'amcic yettrun',
    '😾' => 'amcic imesxenfeṛ',
    '🙈' => 'iddew ur nettwal adɣu',
    '🙉' => 'iddew ur yettḥessisen i udeɣu',
    '🙊' => 'iddew ur nettmeslay ɣef udɣu',
    '💌' => 'tabrat n wul',
    '💘' => 'ul tekka tneccabt',
    '💝' => 'ul s tḥacit',
    '💖' => 'ul yettmecbarriqen',
    '💗' => 'ul igemmun',
    '💓' => 'ul yekkat',
    '💞' => 'ul itezzin',
    '💕' => 'sin wulawen',
    '💟' => 'acebbeḥ n wul',
    '❣' => 'ul ibehten',
    '💔' => 'ul yerẓen',
    '❤' => 'ul azeggaɣ',
    '🩷' => 'ul axuxi',
    '🧡' => 'ul ačini',
    '💛' => 'ul awreɣ',
    '💚' => 'ul azegzaw',
    '💙' => 'ul anili',
    '🩵' => 'ul amidadi',
    '💜' => 'ul ademdam',
    '🤎' => 'ul aqehwi',
    '🖤' => 'ul aberkan',
    '🩶' => 'ul idbar',
    '🤍' => 'ul amellal',
    '💋' => 'later n tsudent',
    '💯' => 'tawinest n tezmilin',
    '💢' => 'azamul n reffu',
    '💫' => 'tuzzya n leεqel',
    '💦' => 'aquder n tidi',
    '💨' => 'tarewla',
    '🕳' => 'amruj',
    '💬' => 'tanaka n wawal',
    '🗨' => 'tanaka n wawal tazelmaḍt',
    '🗯' => 'tanaka n reffu tayeffust',
    '💭' => 'tanaka n tikta',
    '💤' => 'zzz',
    '👋' => 'afus yettwehhin',
    '🤚' => 'talwaḥt n ufus irefden',
    '🖐' => 'afus s yiḍudan yeldin',
    '✋' => 'argaz: acebbub awreɣ',
    '🖖' => 'aburkan n tezmert',
    '🫱' => 'afus ayeffus',
    '🫲' => 'afus azelmaḍ',
    '🫳' => 'tidikelt d akesser',
    '🫴' => 'tidikelt d asawen',
    '🫷' => 'afus ijebden ɣer zelmeḍ',
    '🫸' => 'afus ijebden ɣer yeffus',
    '👌' => 'afus n IH',
    '🤌' => 'Iduḍan yemlalen',
    '🤏' => 'tubbya n ufus',
    '✌' => 'afus n rrbeḥ',
    '🤞' => 'iḍudan yemcubbaken',
    '🫰' => 'afus s udebbuz d ccahed yemcubbaken',
    '🤟' => 'afus n tayri',
    '🤘' => 'azamul n wacciwen',
    '🤙' => 'afus n usiwel',
    '👈' => 'afus s udebbuz yerran s azelmaḍ',
    '👉' => 'afus s udebbuz yerran s ayeffus',
    '👆' => 'afus s udebbuz yerran d asawen',
    '🖕' => 'aḍad alemmas',
    '👇' => 'afus s udebbuz yerran d akesser',
    '☝' => 'ccahed yerran d asawen',
    '🫵' => 'ccahed iwehhan ɣer useqdac',
    '👍' => 'adebbuz d asawen',
    '👎' => 'adebbuz d akessar',
    '✊' => 'arfad n ufus ikersen',
    '👊' => 'awwaḍ n lbunya',
    '🤛' => 'afus ikersen ɣer uzelmaḍ',
    '🤜' => 'afus ikersen ɣer uyeffus',
    '👏' => 'aṣerfeq',
    '🙌' => 'ifassen yulin',
    '🫶' => 'ifassen am wul',
    '👐' => 'ifassen yeldin',
    '🤲' => 'tidikal yeddukklen d asawen',
    '🤝' => 'amsalem',
    '🙏' => 'ifassen ineṭḍen',
    '✍' => 'afus yettarun',
    '💅' => 'iɣmi n waccaren',
    '🤳' => 'asilfi',
    '💪' => 'akras n lbunya',
    '🦾' => 'iɣil n tmacint',
    '🦿' => 'aqejjir n tmacint',
    '🦵' => 'aqejjir',
    '🦶' => 'aḍar',
    '👂' => 'ameẓẓuɣ',
    '🦻' => 'ameẓẓuɣ s ufecku n tmesliwt',
    '👃' => 'anzaren',
    '🧠' => 'allaɣ',
    '🫁' => 'turin',
    '🦷' => 'tuɣmest',
    '🦴' => 'iɣes',
    '👀' => 'allen',
    '👁' => 'tiṭ',
    '👅' => 'iles',
    '👄' => 'imi',
    '🫦' => 'acenfir yettwakercen',
    '👶' => 'aṭufan',
    '🧒' => 'agrud',
    '👦' => 'aqcic',
    '👧' => 'taqcict',
    '🧑' => 'amdan',
    '👱' => 'amdan: acekkuḥ aceɛlal',
    '👨' => 'argaz',
    '🧔' => 'amdan: tamart',
    '👩' => 'tameṭṭut',
    '🧓' => 'amdan meqqren',
    '👴' => 'amɣar',
    '👵' => 'tamɣart',
    '🙍' => 'amdan imexenfeṛ',
    '🙎' => 'amdan imcennef',
    '🧏' => 'amdan aɛeẓẓug',
    '🙇' => 'amdan yettanez',
    '👮' => 'amsaltu',
    '💂' => 'aɛessas',
    '🥷' => 'aninja',
    '🤴' => 'ageldun',
    '👸' => 'tageldunt',
    '👳' => 'amdan s uɛessab',
    '🤰' => 'tameṭṭut s tadist',
    '🫃' => 'argaz s tadist',
    '🫄' => 'amdan s tawist',
    '👼' => 'aṭufan aneglus',
    '🧟' => 'aẓumbi',
    '🧌' => 'aɣuliw',
    '🚶' => 'amdan ileḥḥun',
    '🧍' => 'amdan ibedden',
    '🧎' => 'amdan ɣef tgecrar',
    '🏃' => 'amdan yettazzalen',
    '💃' => 'tameṭṭut iceṭṭḥen',
    '🕺' => 'argaz iceṭṭḥen',
    '👯' => 'imdanen s yimeẓẓuɣen n yiwtal',
    '🚴' => 'amdan s uvilu',
    '🤽' => 'amdan yetturare water polo',
    '🤾' => 'amdan yetturaren ddabex n ufus',
    '🛀' => 'amdan yeccucufen',
    '🛌' => 'amdan deg wusu',
    '👭' => 'tulawin myuṭṭafent ifassen',
    '👫' => 'tameṭṭut d urgaz myuṭṭafen ifassen',
    '👬' => 'irgazen myuṭṭafen ifassen',
    '💑' => 'tayuga s wul',
    '🗣' => 'aqerru yettmeslayen',
    '🫂' => 'imdanen ttemsalamen',
    '👪' => 'tawacult',
    '👣' => 'lǧerra n yiḍarren',
    '🦰' => 'acekkuḥ azeggaɣ',
    '🦱' => 'acekkuḥ akerṭuṭfan',
    '🦳' => 'acekkuḥ amellal',
    '🦲' => 'aferḍas',
    '🐵' => 'aqadum n yibki',
    '🐒' => 'ibki',
    '🦍' => 'aguril',
    '🦧' => 'amdan n teẓgi',
    '🐶' => 'udem n uydi',
    '🐕' => 'aydi',
    '🦮' => 'aydi amaway',
    '🐩' => 'akanic',
    '🐺' => 'aguleh',
    '🦊' => 'abaraɣ',
    '🦝' => 'arakun',
    '🐱' => 'udem n umcic',
    '🐈' => 'amcic',
    '🦁' => 'izem',
    '🐯' => 'udem n uɣilas',
    '🐅' => 'aɣilas',
    '🐆' => 'agiw',
    '🐴' => 'udem n uɛewdiw',
    '🫎' => 'taɣzalt n Marikan',
    '🫏' => 'aɣyul',
    '🐎' => 'aɛewdiw',
    '🦄' => 'bu yiwen n yiccew',
    '🦓' => 'aɣyul n teẓgi',
    '🦌' => 'tizerzert',
    '🦬' => 'aramul n marikan',
    '🐮' => 'udem n tfunast',
    '🐂' => 'azger',
    '🐃' => 'alebbic n waman',
    '🐄' => 'tafunast',
    '🐷' => 'aqadum n uḥelluf',
    '🐖' => 'aḥelluf',
    '🐗' => 'ilef',
    '🐽' => 'tinzarin n uḥelluf',
    '🐏' => 'akrar',
    '🐑' => 'tixsi',
    '🐐' => 'taɣaṭ',
    '🐪' => 'alɣem',
    '🐫' => 'alɣem bu snat n tkeɛrurin',
    '🦙' => 'alama',
    '🦒' => 'amdeɣ',
    '🐘' => 'ilu',
    '🦣' => 'amamut',
    '🦏' => 'arinusirus',
    '🦛' => 'apuputam',
    '🐭' => 'aqadum n uɣerda',
    '🐁' => 'aɣerda',
    '🐀' => 'ṭubba',
    '🐹' => 'ahamester',
    '🐰' => 'udem n uwtul',
    '🐇' => 'awtul',
    '🐿' => 'tadɣaɣat',
    '🦫' => 'akastur',
    '🦔' => 'inisi',
    '🦇' => 'azuɣnennay',
    '🐻' => 'ursu',
    '🐨' => 'akwala',
    '🐼' => 'apanda',
    '🦥' => 'Asellaw',
    '🦦' => 'aselḍ aman',
    '🦨' => 'anziḍ',
    '🦘' => 'akanguru',
    '🦡' => 'isirru',
    '🐾' => 'tirekkiḍin n yiḍarren',
    '🦃' => 'adandu',
    '🐔' => 'tayaziḍt',
    '🐓' => 'ayaziḍ',
    '🐣' => 'acewcew yefrurxen',
    '🐤' => 'acewcew',
    '🐥' => 'afellus si zdat',
    '🐦' => 'agḍiḍ',
    '🐧' => 'ameddul',
    '🕊' => 'itbir',
    '🦅' => 'lbaz',
    '🦆' => 'abṛik',
    '🦢' => 'iblireǧ',
    '🦉' => 'bururu',
    '🦤' => 'adudu',
    '🪶' => 'taricet',
    '🦩' => 'aflaminku',
    '🦚' => 'afrux n ṭawes',
    '🦜' => 'babaɣayu',
    '🪽' => 'taḥemmaṛt',
    '🪿' => 'awezziw',
    '🐸' => 'imqerqer',
    '🐊' => 'aɣucaf',
    '🐢' => 'ifker',
    '🦎' => 'tata',
    '🐍' => 'azrem',
    '🐲' => 'udem n udragu',
    '🐉' => 'adragu',
    '🦕' => 'aṣurupud',
    '🦖' => 'T-Reks',
    '🐳' => 'tizmekt i d-yessufuɣen aman',
    '🐋' => 'tizmekt',
    '🐬' => 'addenfil',
    '🦭' => 'Aydi n waman',
    '🐟' => 'aslem',
    '🐠' => 'aslem amsadaɣan',
    '🐡' => 'aslem icuffen',
    '🦈' => 'awqas',
    '🐙' => 'iqirniḍ',
    '🐚' => 'ajeɣlal yennḍen',
    '🪸' => 'lmerǧan',
    '🦀' => 'tifiraqest',
    '🦐' => 'aqemrun',
    '🦪' => 'idway',
    '🐌' => 'aεarus',
    '🦋' => 'aferteṭṭu',
    '🐛' => 'aburbu',
    '🐜' => 'taweṭṭuft',
    '🐝' => 'tizizwit',
    '🪲' => 'axunefsiw',
    '🐞' => 'takumda',
    '🦗' => 'ajṛad',
    '🪳' => 'akafaṛ',
    '🕷' => 'tissist',
    '🕸' => 'azeṭṭa n tissist',
    '🦂' => 'tiɣirdemt',
    '🦟' => 'tizit',
    '🪰' => 'izi',
    '🪱' => 'ijirmeḍ',
    '🦠' => 'amikṛub',
    '💐' => 'tameqqunt',
    '🌸' => 'ajeğğig n taknisya',
    '💮' => 'ajeğğig amellal',
    '🪷' => 'abelbaquc',
    '🏵' => 'tawerdit',
    '🌹' => 'tawerdet',
    '🥀' => 'ajeğğig akiwan',
    '🌺' => 'tibinṣert',
    '🌻' => 'mageriṭij',
    '🌼' => 'amgud',
    '🌷' => 'taxlult n nnbi',
    '🌱' => 'imɣi aleqqaq',
    '🪴' => 'imɣi deg uḥibus',
    '🌲' => 'aseklu s yifer imezgi',
    '🌳' => 'aseklu bu yifer',
    '🌴' => 'tazdayt',
    '🌵' => 'tasiɣawt',
    '🌾' => 'taceṛṛaft n ṛṛuz',
    '🌿' => 'ifer',
    '☘' => 'ikeffis',
    '🍀' => 'ikeffis bu kuẓ n wafriwen',
    '🍁' => 'ifer n kikeb',
    '🍂' => 'ifer yeɣlin',
    '🍃' => 'ifer yessafag waḍu',
    '🪹' => 'lɛec ilem',
    '🪺' => 'lɛec s tmellalin',
    '🍄' => 'tagerselt',
    '🍇' => 'tiẓurin',
    '🍈' => 'afeqqus',
    '🍉' => 'delleɛ',
    '🍊' => 'tamandarit',
    '🍋' => 'talimet',
    '🍌' => 'tabanant',
    '🍍' => 'tananast',
    '🥭' => 'tamungat',
    '🍎' => 'tatteffaḥt tazeggaɣt',
    '🍏' => 'tatteffaḥt tazegzawt',
    '🍐' => 'ifires',
    '🍑' => 'taxuxet',
    '🍒' => 'areḍli',
    '🍓' => 'tariwalt',
    '🫐' => 'cilmun',
    '🥝' => 'takiwit',
    '🍅' => 'taṭumaṭict',
    '🫒' => 'azemmur',
    '🥥' => 'iɣsan n koko',
    '🥑' => 'tavukat',
    '🍆' => 'patenǧal',
    '🥔' => 'baṭaṭa',
    '🥕' => 'taẓrudgat',
    '🌽' => 'ageṭṭuc',
    '🌶' => 'ifelfel aqerḥan',
    '🫑' => 'ifelfel n leḥlu',
    '🥒' => 'ilekkel',
    '🥬' => 'Tidelt n iferrawen izegzawen',
    '🥦' => 'brukuli',
    '🧄' => 'tiskert',
    '🧅' => 'aẓalim',
    '🥜' => 'kawkaw',
    '🫘' => 'llubyan',
    '🌰' => 'abelluḍ n urumi',
    '🫚' => 'aẓar n skenǧbir',
    '🫛' => 'taxeddact n tjilbant',
    '🍞' => 'aɣrum',
    '🥐' => 'akarwasun',
    '🥖' => 'tabagiḍt n uɣrum',
    '🫓' => 'taḥbult n uɣrum',
    '🥨' => 'bretzel',
    '🥯' => 'abinyi',
    '🍗' => 'tamessaḍt n uyaziḍ',
    '🥩' => 'tacriḥt n uksum',
    '🥪' => 'aṣundwic',
    '🥚' => 'tamellalt',
    '🍳' => 'tamellalt yewwan',
    '🍲' => 'taqessult n tgella',
    '🫕' => 'taḥelwiḍt',
    '🥣' => 'aḍebdi s tejɣelt',
    '🥗' => 'cclaḍa tazegzawt',
    '🍿' => 'akbal icuffen',
    '🧈' => 'udi',
    '🧂' => 'tisent',
    '🥫' => 'tagella n tbewwaḍt',
    '🍱' => 'tbewwaḍt Bintu',
    '🍘' => 'tiḥbulin n ṛṛuz',
    '🍙' => 'takurt n ṛṛuz',
    '🍚' => 'rruẓ yewwan',
    '🍝' => 'spagiti',
    '🍠' => 'baṭaṭa taẓidant ikenfen',
    '🍢' => 'tifarrugt',
    '🍣' => 'aṣuci',
    '🍫' => 'tabewwaḍt n ccakula',
    '🍬' => 'taḥlawat',
    '🍭' => 'tameccaḥt',
    '🍯' => 'tabellaṛt n tament',
    '🍼' => 'abibṛu',
    '🥛' => 'lkas n uyefki',
    '🫖' => 'tabaqrajt n latay',
    '🍵' => 'afenǧal n latay war afus',
    '🍶' => 'taqerɛunt n uyefki d lkas',
    '🍾' => 'taqerɛunt s ubucun ineṭwen',
    '🍷' => 'lkas n ccṛab',
    '🍺' => 'abuqal n tebyiṛt',
    '🍻' => 'asčenčen n yibuqal n tebyiṛt',
    '🥂' => 'asčenčen n lkisan',
    '🧊' => 'agris',
    '🥢' => 'tileqqaḍin',
    '🍽' => 'tafarciḍt d lmus s uḍebsi',
    '🍴' => 'tafarciḍt d lmus',
    '🥄' => 'tijɣelt',
    '🔪' => 'tafruyt n usaččet',
    '🫙' => 'tabellaṛt',
    '🏺' => 'tabuqalt',
    '🌍' => 'amtiweg turuft tafriqt',
    '🌎' => 'amtiweg timrikin',
    '🌏' => 'amtiweg asya ustralya',
    '🗺' => 'takarḍa n umaḍal',
    '🗾' => 'takarḍa n Japun',
    '🧭' => 'tabuṣult',
    '🏔' => 'adrar n udfel',
    '⛰' => 'adrar',
    '🌋' => 'avulkan',
    '🗻' => 'Taqacuct Fuji',
    '🏕' => 'asdar',
    '🏖' => 'taftisft d ssiwan',
    '🏜' => 'aneẓruf',
    '🏝' => 'tigzirt taneẓruft',
    '🏞' => 'amṛaḥ aɣelnaw',
    '🏟' => 'annar',
    '🏛' => 'amedruz aklasikan',
    '🏗' => 'bennu n uzadaɣ',
    '🧱' => 'Tayajuṛt',
    '🪨' => 'ablaḍ',
    '🪵' => 'asɣar',
    '🛖' => 'atemmu',
    '🏘' => 'ixxamen',
    '🏚' => 'axxam yettwaḍeggren',
    '🏠' => 'axxam',
    '🏡' => 'axxam s tmazirt',
    '🏢' => 'azadaɣ n tnariyin',
    '🏣' => 'tanazant tajapunit',
    '🏤' => 'tanarit n tnazant',
    '🏥' => 'Asegnaf',
    '🏦' => 'tabanka',
    '🏨' => 'asensu',
    '🏩' => 'asensu n tayri',
    '🏪' => 'talzuzt',
    '🏫' => 'aɣerbaz',
    '🏬' => 'taḥanut meqqren',
    '🏭' => 'taneɣraft',
    '🏯' => 'tiɣremt tajapunit',
    '🏰' => 'tiɣremt',
    '💒' => 'tissulya',
    '🗼' => 'Tiɣremt n Tokyo',
    '🗽' => 'asebdad n tlelli',
    '⛪' => 'tamezgida n yimasiḥiyen',
    '🕌' => 'tamezgida n yinselmen',
    '🛕' => 'tamesgida handu',
    '🕍' => 'tamezgida n wudayen',
    '⛩' => 'asebdad shrine',
    '🕋' => 'lkaɛva',
    '⛲' => 'tala',
    '⛺' => 'aqiḍun',
    '🌁' => 'agu',
    '🌃' => 'iḍ s yitran',
    '🏙' => 'tamdint',
    '🌄' => 'alluy n yiṭij ɣef yidurar',
    '🌅' => 'alluy n yiṭij',
    '🌇' => 'aɣelluy n yiṭij',
    '🌉' => 'tiqenṭert deg yiḍ',
    '♨' => 'lḥemmam',
    '🚂' => 'aqerru n tmacint',
    '🚃' => 'abrid n tmacint',
    '🚇' => 'amitṛu',
    '🚈' => 'amitru afess',
    '🚓' => 'Takerrust n temsulta',
    '🚕' => 'Ataksi',
    '🚗' => 'Takerrust',
    '🛹' => 'avilu',
    '🚨' => 'Taftilt n tkerrust n tmsulta',
    '✈' => 'asafag',
    '🛩' => 'asafag ameẓyan',
    '💺' => 'tasɣimt',
    '🚁' => 'talikuptirt',
    '🛰' => 'Aṣatilit',
    '🛸' => 'taɣawsa tarussint yettafgen',
    '⌛' => 'tamrilt n ijdan',
    '⏳' => 'tamrilt n ijdan yettmirin',
    '⌚' => 'tamrilt',
    '⏱' => 'amesnakud',
    '⏲' => 'Asakway',
    '🌡' => 'atirmumitr',
    '☀' => 'iṭij',
    '☁' => 'asigna',
    '⛅' => 'iṭij deffir n usigna',
    '🌫' => 'tagut',
    '🌈' => 'tislit n unẓar',
    '🌂' => 'ssiwan imedlen',
    '☂' => 'ssiwan',
    '☔' => 'ssiwan s tmeqqwa n waman',
    '⛱' => 'ssiwan ɣef tmurt',
    '⚡' => 'lebreq',
    '❄' => 'adfel',
    '☃' => 'argaz n udfel',
    '⛄' => 'argazn udfel s war adfel',
    '🔥' => 'times',
    '💧' => 'timeqqit',
    '🌊' => 'lmuja n waman',
    '🎃' => 'taxsayt',
    '🎄' => 'aseklu n nawel',
    '🎆' => 'asfugel',
    '🎇' => 'ifṭiwej',
    '🧨' => 'aḥerbi',
    '✨' => 'itran',
    '🎈' => 'tacuffut',
    '🧧' => 'tabrat tazeggaɣt',
    '🎫' => 'atiki',
    '🎖' => 'cciɛa taserdasant',
    '🏆' => 'arraz',
    '🏅' => 'cciɛa n waddal',
    '🥇' => 'cciɛa n umḍiq 1u',
    '🥈' => 'cciɛa n umḍiq wis 2',
    '🥉' => 'cciɛa n umḍiq wis 3',
    '⚽' => 'ddabex n uḍar',
    '🏓' => 'ping pung',
    '🏸' => 'badminṭun',
    '🔮' => 'takurt n ukrisṭal',
    '🎮' => 'urar n tvidyut',
    '🎴' => 'tikarḍiwin n wurra n ujeǧǧig',
    '🎭' => 'igelmusen',
    '🖼' => 'tugna s ukatar',
    '🧵' => 'lqezz',
    '🪡' => 'tisegnit n lexyaḍa',
    '🧶' => 'takurt n lxiḍ',
    '🪢' => 'tikerrist',
    '👓' => 'tismaqqalin',
    '🕶' => 'nnwaḍer n yiṭij',
    '🥽' => 'nnwaḍer n uḥader',
    '🥼' => 'tavluzt n ulabuṛatwar',
    '🦺' => 'ajili n tɣellist',
    '👔' => 'takravaḍt',
    '👕' => 'amayut',
    '👖' => 'aserwal',
    '🧣' => 'akackul',
    '🧤' => 'iqeffazen',
    '🧥' => 'abaltu',
    '🧦' => 'iqaciren',
    '👗' => 'taqendurt',
    '👘' => 'akimunu',
    '🥻' => 'asari',
    '🩱' => 'amayut n ucucef ɣef yiwen',
    '🩲' => 'takiluḍt',
    '🩳' => 'abirmida',
    '👙' => 'abikini',
    '👚' => 'iceṭṭiḍen n tlawin',
    '🪭' => 'tasebuḥrut',
    '👛' => 'ṣṣak',
    '👜' => 'taṣakuct',
    '👝' => 'taxriḍt',
    '🛍' => 'aḍellaɛ',
    '🎒' => 'ṣṣak n waɛrur',
    '🩴' => 'taklakiḍt',
    '👞' => 'iṣebbaḍen n urgaz',
    '👟' => 'iṣebbaḍen n tazzla',
    '🥾' => 'iṣebbaḍen n tikli',
    '🥿' => 'tibelɣatin',
    '👠' => 'asebbaḍ n talu ɣezzifen',
    '👡' => 'asundal n tlawin',
    '🩰' => 'isebbaḍen n ccḍeḥ',
    '👢' => 'abutyu n tlawin',
    '🪮' => 'asellak',
    '👑' => 'Taɛessabt n ugellid',
    '👒' => 'Timḍelliwt n tmeṭṭut',
    '🎩' => 'acapun aɣezfan',
    '🎓' => 'takaskiḍt n usdawan',
    '🧢' => 'takaskiḍt',
    '🪖' => 'takaskiḍt n userdas',
    '⛑' => 'akaskiḍ amidag amellal',
    '📿' => 'teṣbiḥ',
    '💄' => 'zzin aγec',
    '💍' => 'taxatemt',
    '💎' => 'aẓru ɣlayen',
    '🔇' => 'asusam',
    '🔈' => 'imesli meẓẓiyen',
    '🔉' => 'imesli alemmas',
    '🔊' => 'imesli meqqren',
    '📢' => 'imsemɣer n yimesli',
    '📣' => 'amigafun',
    '📯' => 'ajewwaq ubrin',
    '🔔' => 'aninay',
    '🔕' => 'aninay yegdel',
    '🎼' => 'tagrumma n tezmilin n uẓawan',
    '🎵' => 'tazmilt taẓawant',
    '🎶' => 'tizmilin tiẓawanin',
    '🎙' => 'asawaḍ n uxxam n usekles',
    '🎚' => 'taḥnaccaḍt n uswir',
    '🎛' => 'tiqeffalin n uṣeggem',
    '🎤' => 'asawaḍ',
    '🎧' => 'Ismazgaten',
    '📻' => 'rradyu',
    '🎷' => 'asaksufun',
    '🪗' => 'akudiyun',
    '🎸' => 'snitra',
    '🎹' => 'anasiw amẓawan',
    '🪕' => 'abanju',
    '🥁' => 'ṭṭbel',
    '🪈' => 'tajewwaqt',
    '📱' => 'tiliɣri tazirazt',
    '📲' => 'tiliɣri tazirazt s uneccab',
    '☎' => 'tiliɣri',
    '📞' => 'imsuddes n tiliɣri',
    '📠' => 'tamacint n unɣel',
    '🔋' => 'aẓru',
    '🪫' => 'aẓru yeɛyan',
    '💻' => 'aselkim aziraz',
    '🖥' => 'aselkim n tnarit',
    '🖨' => 'tasaggazt',
    '⌨' => 'anasiw',
    '🖱' => 'taɣerdayt n uselkim',
    '💽' => 'aḍebsi n uselkim',
    '💾' => 'adebṣi aleqqaq',
    '💿' => 'aḍebsi asekdan',
    '📀' => 'dvd',
    '🧮' => 'abakus',
    '🎥' => 'takamiṛat n yisura',
    '📽' => 'ameskan n yisura',
    '📺' => 'tiliẓri',
    '📷' => 'Takamiṛat',
    '🕯' => 'tacemmuεt',
    '📔' => 'imedlis s tduli icebḥen',
    '📕' => 'adlis imedlen',
    '📖' => 'adlis yeldin',
    '📗' => 'adlis azegzaw',
    '📘' => 'adlis amidadi',
    '📙' => 'adlis ačinawi',
    '📚' => 'idlisen',
    '📓' => 'imedlis',
    '📒' => 'ambellez',
    '📃' => 'asebter yennḍen',
    '📜' => 'adrurem',
    '📄' => 'asebter',
    '📰' => 'aɣmis',
    '🗞' => 'aɣùis yennḍen',
    '📑' => 'accaren n tecraḍ',
    '🔖' => 'tacreṭ n usebter',
    '🏷' => 'tabzimt',
    '🪙' => 'aṣurdi',
    '💰' => 'sselfa',
    '💴' => 'lkaɣeḍ n yen',
    '💵' => 'lkaɣeḍ n udular',
    '💶' => 'lkareḍ n uru',
    '💷' => 'lkaɣeḍ n upawnd',
    '💸' => 'idrimen s yiferrawen',
    '💳' => 'takarḍa n usmad',
    '🧾' => 'awwaḍ',
    '✉' => 'tajellabt',
    '📧' => 'imayl',
    '📨' => 'izen ukcim',
    '📩' => 'izen yettwazen',
    '📤' => 'tanaka n tuzna',
    '📥' => 'tanaka n urmas',
    '📦' => 'akemmus',
    '🗳' => 'asenduq',
    '✏' => 'aɣnib',
    '✒' => 'imru n tricet aberkan',
    '🖋' => 'imru n lmidad',
    '🖊' => 'imru',
    '🖌' => 'rrica',
    '🖍' => 'akeryun',
    '💼' => 'aqrab',
    '📁' => 'akaram n ufaylu',
    '📂' => 'ldi akaram n ufaylu',
    '📅' => 'awitay',
    '📆' => 'awitay yettwakksen',
    '📋' => 'ɣef wafus',
    '✂' => 'timqestin',
    '🔒' => 'yemdel',
    '🔓' => 'yeldi',
    '🔏' => 'yemdel s yimru',
    '🔐' => 'yemdel s tsarut',
    '🔑' => 'tasarut',
    '🗝' => 'tasarut taqdimt',
    '🔨' => 'tafḍist',
    '🪓' => 'tacaqurt',
    '⛏' => 'agelzim',
    '⚒' => 'afḍis d ugelzim',
    '🛡' => 'abeckiḍ',
    '🔗' => 'aseɣwen',
    '⛓' => 'snesla',
    '🧬' => 'dna',
    '🔬' => 'amikruskup',
    '🔭' => 'atiliskup',
    '💉' => 'tisegnit',
    '🩸' => 'tiqiit n yidammen',
    '🚪' => 'tabburt',
    '🛏' => 'ameṭreḥ',
    '🪑' => 'akersi',
    '🧹' => 'imeṣleḥ',
    '🧺' => 'taqecwalt',
    '🪣' => 'abelyun',
    '🧼' => 'ṣṣabun',
    '🪥' => 'ccita n tuɣmas',
    '🧯' => 'imsexsi',
    '🛒' => 'taqecwalt n tiɣin',
    '🚬' => 'ageṛṛu',
    '⚰' => 'nneɛc',
    '🪦' => 'ccahed',
    '🪬' => 'lxamsa',
    '🪧' => 'tafilt',
    '🪪' => 'takarḍa n timagit',
    '🏧' => 'tamacint n tedrimt tawurmant',
    '🚮' => 'tignit n yiḍumman',
    '🚰' => 'aman n tissit',
    '♿' => 'azamul n unekcum n umeɛduṛ',
    '🚹' => 'taxxamt n urgaz',
    '🚺' => 'azamul n texxamt n tmeṭṭut',
    '🚻' => 'azamul n teslalayt',
    '🚼' => 'azamul n uṭufan',
    '🚾' => 'taslalayt',
    '🛂' => 'asenqed n umsineg',
    '🛃' => 'tadewwant',
    '🛄' => 'asuter n dduzan',
    '🛅' => 'dduzan yettwattun',
    '⚠' => 'aberri',
    '🚸' => 'abrid n yigerdan',
    '⛔' => 'aɛeddi yegdel',
    '🚫' => 'yegdel',
    '🚳' => 'avilu yegdel',
    '🚭' => 'akeyyef yegdel',
    '🚯' => 'ur ttḍeyyir ara iḍumman',
    '🚱' => 'mačči d aman n tissit',
    '🚷' => 'igdel i yimesḍaṛen',
    '📵' => 'tiliɣri n ufus tegdel',
    '🔞' => 'yegdel ddaw n tmenṭac',
    '⬆' => 'aneccab d asawen',
    '↗' => 'aneccab asawen ayeffus',
    '➡' => 'aneccab ayeffus',
    '↘' => 'aneccab d akesser uẓẓil',
    '⬇' => 'aneccab akesser',
    '↙' => 'aneccab akesser ayeffus',
    '⬅' => 'aneccab azelmaḍ',
    '↖' => 'aneccab asawen azelmaḍ',
    '↕' => 'aneccab asawen akesser',
    '↔' => 'aneccab azelmaḍ ayeffus',
    '↩' => 'aneccab ayeffus yettin s azelmaḍ',
    '↪' => 'aneccab azelmaḍ yettin s ayeffus',
    '⤴' => 'aneccab ayeffus yettin d asawen',
    '⤵' => 'aneccab ayeffus yettin d akesser',
    '🔃' => 'ineccaben tanila n isegnan n temrilt',
    '🔄' => 'taqeffalt n ineccaben n tnila yettin n isegnan n temrilt',
    '🔙' => 'Aneccab n tuɣalin',
    '🔚' => 'Aneccab n taggara',
    '🔛' => 'urmid',
    '🔜' => 'Aneccab Qrib',
    '🔝' => 'aneccab n ufella',
    '🛐' => 'amḍiq n tẓallit',
    '⚛' => 'azamul n ubelkim',
    '🕉' => 'om',
    '✡' => 'itri n David',
    '☸' => 'Rruda n dharma',
    '☯' => 'yin yang',
    '☪' => 'aggur d yitri',
    '☮' => 'azamul n talwit',
    '♈' => 'Ikerri',
    '♉' => 'Aramul',
    '♊' => 'Akniwen',
    '♋' => 'Afurray',
    '♍' => 'Taḥbayrit',
    '♎' => 'Tacihant',
    '♐' => 'Amnaccab',
    '♑' => 'Aqelwac',
    '♒' => 'Azfuf',
    '♓' => 'Islem',
    '⛎' => 'Aẓudyak',
    '🔀' => 'Aneccab anmidag',
    '🔁' => 'aneccab imdewweṛ',
    '▶' => 'taqeffalt n tɣuri',
    '⏩' => 'taqeffalt n uɣiwel ɣer zdat',
    '⏭' => 'taqeffalt tafuɣalt d-iteddun',
    '⏯' => 'taqeffalt taɣuri/araǧu',
    '◀' => 'taqeffalt n tuɣalin',
    '⏪' => 'taqeffalt n tuɣalin s uɣiwel',
    '⏮' => 'taqeffalt tafuɣalt taneggarut',
    '🔼' => 'taqeffalt d asawen',
    '⏫' => 'taqeffalt n usɣiwel',
    '🔽' => 'taqeffalt d akesser',
    '⏬' => 'taqeffant n uṣubbu s uɣiwel',
    '⏸' => 'taqeffalt n uraǧu',
    '⏹' => 'taqeffalt n useḥbes',
    '⏺' => 'taqeffalt n usekles',
    '⏏' => 'taqeffalt n tukksa',
    '🎦' => 'sinima',
    '♀' => 'azamul n tewtemt',
    '♂' => 'azamul n uwtem',
    '⚧' => 'Azamul n bu snat n tewsatin',
    '✖' => 'asgat',
    '➕' => 'timerna',
    '➖' => 'asenɣes',
    '➗' => 'beṭṭu',
    '🟰' => 'geddu',
    '♾' => 'war talast',
    '‼' => 'asɣal n ubhat uslig',
    '❗' => 'asɣal n ubhat azeggaɣ',
    '🆒' => 'taqeffalt COOL',
    '🆓' => 'taqeffalt FREE',
    'ℹ' => 'talɣut',
    '🆔' => 'taqeffalt ID',
    '🟣' => 'tawinest tademdamt',
    '🟥' => 'amkuẓ azeggaɣ',
    '🟧' => 'amkuẓ aččinawi',
    '🟨' => 'amkuẓ awreɣ',
    '🟩' => 'amkuẓ azegzaw',
    '🟦' => 'amkuẓ amidadi',
    '🟪' => 'amkuẓ ademdam',
    '🟫' => 'amkuẓ aqehwi',
    '⬛' => 'amkuẓ aberkan ameqqran',
    '⬜' => 'amkuẓ amellal ameqqran',
    '🏁' => 'anay s texxamin',
    '🚩' => 'anay azeggaɣ',
    '🎌' => 'anayen ijapuniyen',
    '🏴' => 'anay aberkan',
    '🏳' => 'anay amellal',
];
